/*
 *******************************************************************************
 *
 *  Copyright 2025 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 */

#ifndef RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
#define RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87

#include <vector>
#include <string>
#include <cstdlib>
#include <cstdint>

namespace riegl {
namespace rdb {
namespace pointcloud {

// Meta data item definition version
const std::string RDB_META_DATA_ITEMS_VERSION = "1.1.54";
const std::string RDB_META_DATA_ITEMS_DATE = "2023-01-19";

// Meta data item states
const unsigned char RDB_STATUS_REQUIRED = 1; // mandatory item
const unsigned char RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
struct MetaDataItemInfo
{
    std::string   name;
    std::string   title;
    std::string   description;
    unsigned char status;
    std::string   schema;
    std::string   example;

    operator const std::string&() const { return name; }
};

// Angular notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_ANGULAR_NOTCH_FILTER = {
    /* name        */ "riegl.angular_notch_filter",
    /* title       */ "Angular Notch Filter",
    /* description */ "Angular notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Angular notch filter parameters for window glass "
    "echoes\",\"properties\":{\"range_mean\":{\"description\":\"Mean range [m]\",\"it"
    "ems\":{\"type\":\"number\"},\"type\":\"array\"},\"angle\":{\"description\":\"Angle ["
    "deg]\",\"items\":{\"type\":\"number\"},\"type\":\"array\"},\"amplitude_mean\":{\"des"
    "cription\":\"Mean amplitude "
    "[dB]\",\"items\":{\"type\":\"number\"},\"type\":\"array\"}},\"title\":\"Angular "
    "Notch Filter\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"typ"
    "e\":\"object\",\"required\":[\"angle\",\"range_mean\",\"amplitude_mean\"]}"
    ,
    /* example: */
    "{\"range_mean\":[0.094,0.094,0.09075,0.08675,0.0815,0.0775,0.074,0.071,0"
    ".068,0.0675,0.06475],\"angle\":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,"
    "22.0,23.0,24.0],\"amplitude_mean\":[3.780913,3.780913,3.480913,3.120913,"
    "2.850913,2.720913,2.680913,2.610913,2.530913,2.570913,2.570913]}"
};

// Atmospheric parameters
const MetaDataItemInfo RDB_RIEGL_ATMOSPHERE = {
    /* name        */ "riegl.atmosphere",
    /* title       */ "Atmosphere",
    /* description */ "Atmospheric parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Atmospheric "
    "parameters\",\"properties\":{\"wavelength\":{\"description\":\"Laser "
    "wavelength "
    "[nm]\",\"type\":\"number\"},\"pressure_sl\":{\"description\":\"Atmospheric "
    "pressure at sea level "
    "[mbar]\",\"type\":\"number\"},\"attenuation\":{\"description\":\"Atmospheric "
    "attenuation "
    "[1/km]\",\"type\":\"number\"},\"temperature\":{\"description\":\"Temperature "
    "along measurement path "
    "[\\u00b0C]\",\"type\":\"number\"},\"amsl\":{\"description\":\"Height above mean "
    "sea level (AMSL) "
    "[m]\",\"type\":\"number\"},\"pressure\":{\"description\":\"Pressure along "
    "measurment path "
    "[mbar]\",\"type\":\"number\"},\"rel_humidity\":{\"description\":\"Relative "
    "humidity along measurement path "
    "[%]\",\"type\":\"number\"},\"group_velocity\":{\"description\":\"Group velocity "
    "of laser beam [m/s]\",\"type\":\"number\"}},\"title\":\"Atmospheric Parameters"
    "\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\","
    "\"required\":[\"temperature\",\"pressure\",\"rel_humidity\",\"pressure_sl\",\"ams"
    "l\",\"group_velocity\",\"attenuation\",\"wavelength\"]}"
    ,
    /* example: */
    "{\"wavelength\":1550,\"pressure_sl\":970,\"attenuation\":0.028125,\"temperatu"
    "re\":7,\"amsl\":0,\"pressure\":970,\"rel_humidity\":63,\"group_velocity\":29971"
    "1000.0}"
};

// Laser beam geometry details
const MetaDataItemInfo RDB_RIEGL_BEAM_GEOMETRY = {
    /* name        */ "riegl.beam_geometry",
    /* title       */ "Beam Geometry",
    /* description */ "Laser beam geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Laser beam geometry "
    "details\",\"properties\":{\"beam_exit_diameter\":{\"description\":\"Beam width"
    " at exit aperture [m]\",\"minimum\":0,\"exclusiveMinimum\":false,\"type\":\"nu"
    "mber\"},\"beam_divergence\":{\"description\":\"Beam divergence in far field "
    "[rad]\",\"minimum\":0,\"exclusiveMinimum\":false,\"type\":\"number\"}},\"title\":"
    "\"Beam Geometry\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"t"
    "ype\":\"object\",\"required\":[\"beam_exit_diameter\",\"beam_divergence\"]}"
    ,
    /* example: */
    "{\"beam_exit_diameter\":0.0072,\"beam_divergence\":0.0003}"
};

// List of control object type definitions
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_CATALOG = {
    /* name        */ "riegl.control_object_catalog",
    /* title       */ "Control Object Catalog",
    /* description */ "List of control object type definitions",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"List of control object type definitions\",\"properties\":"
    "{\"types\":{\"uniqueItems\":true,\"items\":{\"oneOf\":[{\"$ref\":\"#/definitions/"
    "rectangle\"},{\"$ref\":\"#/definitions/checkerboard2x2\"},{\"$ref\":\"#/defini"
    "tions/chevron\"},{\"$ref\":\"#/definitions/circular_disk\"},{\"$ref\":\"#/defi"
    "nitions/cylinder\"},{\"$ref\":\"#/definitions/sphere\"},{\"$ref\":\"#/definiti"
    "ons/round_corner_cube_prism\"}],\"type\":\"object\"},\"type\":\"array\"}},\"titl"
    "e\":\"Control Object Catalog\",\"$schema\":\"http://json-schema.org/draft-04"
    "/schema#\",\"type\":\"object\",\"required\":[\"types\"],\"definitions\":{\"round_c"
    "orner_cube_prism\":{\"description\":\"round corner cube "
    "prism\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"description\":\"round "
    "corner cube prism specific "
    "properties\",\"properties\":{\"shape\":{\"description\":\"shape identifier\",\"e"
    "num\":[\"round_corner_cube_prism\"],\"type\":\"string\"},\"offset\":{\"descripti"
    "on\":\"offset in meters, e.g. reflector constant "
    "(optional)\",\"type\":\"number\"},\"diameter\":{\"description\":\"diameter in me"
    "ters\",\"minimum\":0,\"exclusiveMinimum\":true,\"type\":\"number\"}},\"required\""
    ":[\"shape\",\"diameter\"],\"type\":\"object\"}],\"type\":\"object\"},\"cylinder\":{\""
    "description\":\"cylinder\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"des"
    "cription\":\"cylinder specific "
    "properties\",\"properties\":{\"shape\":{\"description\":\"shape identifier\",\"e"
    "num\":[\"cylinder\"],\"type\":\"string\"},\"height\":{\"description\":\"height in "
    "meters\",\"minimum\":0,\"exclusiveMinimum\":true,\"type\":\"number\"},\"diameter"
    "\":{\"description\":\"diameter in meters\",\"minimum\":0,\"exclusiveMinimum\":t"
    "rue,\"type\":\"number\"}},\"required\":[\"shape\",\"diameter\",\"height\"],\"type\":"
    "\"object\"}],\"type\":\"object\"},\"checkerboard2x2\":{\"description\":\"checkerb"
    "oard 2 by 2\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"description\":\""
    "checkerboard specific "
    "properties\",\"properties\":{\"square_length\":{\"description\":\"length of a "
    "square of the checkerboard in meters\",\"minimum\":0,\"exclusiveMinimum\":t"
    "rue,\"type\":\"number\"},\"shape\":{\"description\":\"shape identifier\",\"enum\":"
    "[\"checkerboard2x2\"],\"type\":\"string\"}},\"required\":[\"shape\",\"square_leng"
    "th\"],\"type\":\"object\"}],\"type\":\"object\"},\"circular_disk\":{\"description\""
    ":\"circular disk\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"descriptio"
    "n\":\"circular disk specific "
    "properties\",\"properties\":{\"shape\":{\"description\":\"shape identifier\",\"e"
    "num\":[\"circular_disk\"],\"type\":\"string\"},\"offset\":{\"description\":\"offse"
    "t in meters, e.g. reflector constant "
    "(optional)\",\"type\":\"number\"},\"diameter\":{\"description\":\"diameter in me"
    "ters\",\"minimum\":0,\"exclusiveMinimum\":true,\"type\":\"number\"}},\"required\""
    ":[\"shape\",\"diameter\"],\"type\":\"object\"}],\"type\":\"object\"},\"common\":{\"de"
    "scription\":\"common object "
    "properties\",\"properties\":{\"description\":{\"description\":\"string "
    "describing the "
    "object\",\"type\":\"string\"},\"surface_type\":{\"description\":\"surface "
    "material type\",\"enum\":[\"retro_reflective_foil\",\"diffuse\"],\"type\":\"stri"
    "ng\"},\"shape\":{\"description\":\"shape identifier\",\"enum\":[\"rectangle\",\"ch"
    "eckerboard2x2\",\"chevron\",\"circular_disk\",\"cylinder\",\"sphere\",\"round_co"
    "rner_cube_prism\"],\"type\":\"string\"},\"name\":{\"description\":\"unique type "
    "identifier\",\"minLength\":3,\"type\":\"string\"}},\"required\":[\"name\",\"shape\""
    "],\"type\":\"object\"},\"sphere\":{\"description\":\"sphere\",\"allOf\":[{\"$ref\":\""
    "#/definitions/common\"},{\"description\":\"sphere specific "
    "properties\",\"properties\":{\"shape\":{\"description\":\"shape identifier\",\"e"
    "num\":[\"sphere\"],\"type\":\"string\"},\"diameter\":{\"description\":\"diameter "
    "in meters\",\"minimum\":0,\"exclusiveMinimum\":true,\"type\":\"number\"}},\"requ"
    "ired\":[\"shape\",\"diameter\"],\"type\":\"object\"}],\"type\":\"object\"},\"chevron"
    "\":{\"description\":\"chevron\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\""
    "description\":\"chevron specific "
    "properties\",\"properties\":{\"outside_edge_length\":{\"description\":\"length"
    " of the two outer edges in meters\",\"minimum\":0,\"exclusiveMinimum\":true"
    ",\"type\":\"number\"},\"shape\":{\"description\":\"shape identifier\",\"enum\":[\"c"
    "hevron\"],\"type\":\"string\"},\"thickness\":{\"description\":\"thickness in met"
    "ers\",\"minimum\":0,\"exclusiveMinimum\":true,\"type\":\"number\"}},\"required\":"
    "[\"shape\",\"outside_edge_length\",\"thickness\"],\"type\":\"object\"}],\"type\":\""
    "object\"},\"rectangle\":{\"description\":\"rectangle\",\"allOf\":[{\"$ref\":\"#/de"
    "finitions/common\"},{\"description\":\"rectangle specific "
    "properties\",\"properties\":{\"width\":{\"description\":\"width in meters\",\"mi"
    "nimum\":0,\"exclusiveMinimum\":true,\"type\":\"number\"},\"shape\":{\"enum\":[\"re"
    "ctangle\"],\"type\":\"string\"},\"length\":{\"description\":\"length in meters\","
    "\"minimum\":0,\"exclusiveMinimum\":true,\"type\":\"number\"}},\"required\":[\"sha"
    "pe\",\"length\",\"width\"],\"type\":\"object\"}],\"type\":\"object\"}}}"
    ,
    /* example: */
    "{\"comments\":[\"This file contains a list of control object types (aka. "
    "'catalog').\",\"Each type is described by an object,\",\"which must "
    "contain at least the following parameters:\",\"  - name: unique "
    "identifier of the type\",\"  - shape: one of the following supported "
    "shapes:\",\"      - rectangle\",\"      - checkerboard2x2\",\"      - "
    "chevron\",\"      - circular_disk\",\"      - cylinder\",\"      - sphere\",\""
    "      - round_corner_cube_prism\",\"Depending on 'shape', the following "
    "parameters must/may be specified:\",\"  - rectangle:\",\"      - length: "
    "length in meters\",\"      - width: width in meters\",\"  - "
    "checkerboard2x2:\",\"      - square_length: length of a square of the "
    "checkerboard in meters\",\"  - circular_disk:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"  - chevron:\",\"      - outside_edge_length: "
    "length of the two outer edges in meters\",\"      - thickness: thickness"
    " in meters\",\"  - cylinder:\",\"      - diameter: diameter in meters\",\""
    "      - height: height in meters\",\"  - sphere:\",\"      - diameter: "
    "diameter in meters\",\"  - round_corner_cube_prism:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"Optional parameters:\",\"    - description: string"
    " describing the object\",\"    - surface_type: surface material type "
    "(either 'retro_reflective_foil' or "
    "'diffuse')\"],\"types\":[{\"description\":\"Rectangle (60cm x "
    "30cm)\",\"width\":0.3,\"shape\":\"rectangle\",\"name\":\"Rectangle "
    "60x30\",\"length\":0.6},{\"description\":\"Rectangle (80cm x "
    "40cm)\",\"width\":0.4,\"shape\":\"rectangle\",\"name\":\"Rectangle "
    "80x40\",\"length\":0.8},{\"description\":\"Checkerboard (square length: 30cm"
    ")\",\"square_length\":0.3,\"shape\":\"checkerboard2x2\",\"name\":\"Checkerboard2"
    "x2 30\"},{\"description\":\"Checkerboard (square length: 50cm)\",\"square_le"
    "ngth\":0.5,\"shape\":\"checkerboard2x2\",\"name\":\"Checkerboard2x2 "
    "50\"},{\"description\":\"Chevron (a=24''; b=4'')\",\"outside_edge_length\":0."
    "6096,\"shape\":\"chevron\",\"thickness\":0.1016,\"name\":\"Chevron "
    "24''/4''\"},{\"description\":\" Circular Disk (diameter: 50cm)\",\"surface_t"
    "ype\":\"diffuse\",\"shape\":\"circular_disk\",\"diameter\":0.5,\"name\":\"Circular"
    " Disk 50\"},{\"description\":\"flat circular reflector from "
    "retro-reflective "
    "foil\",\"surface_type\":\"retro_reflective_foil\",\"name\":\"RIEGL flat "
    "reflector 50 mm\",\"diameter\":0.05,\"shape\":\"circular_disk\",\"offset\":0.0}"
    ",{\"description\":\"flat circular reflector from retro-reflective "
    "foil\",\"surface_type\":\"retro_reflective_foil\",\"name\":\"RIEGL flat "
    "reflector 100 mm\",\"diameter\":0.1,\"shape\":\"circular_disk\",\"offset\":0.0}"
    ",{\"description\":\"flat circular reflector from retro-reflective "
    "foil\",\"surface_type\":\"retro_reflective_foil\",\"name\":\"RIEGL flat "
    "reflector 150 mm\",\"diameter\":0.15,\"shape\":\"circular_disk\",\"offset\":0.0"
    "},{\"description\":\"cylindrical reflector from retro-reflective "
    "foil\",\"surface_type\":\"retro_reflective_foil\",\"name\":\"RIEGL cylindrical"
    " reflector 50 mm\",\"diameter\":0.05,\"shape\":\"cylinder\",\"height\":0.05},{\""
    "description\":\"cylindrical reflector from retro-reflective "
    "foil\",\"surface_type\":\"retro_reflective_foil\",\"name\":\"RIEGL cylindrical"
    " reflector 100 mm\",\"diameter\":0.1,\"shape\":\"cylinder\",\"height\":0.1},{\"d"
    "escription\":\"Sphere (diameter: 200 "
    "mm)\",\"shape\":\"sphere\",\"diameter\":0.2,\"name\":\"Sphere 200 "
    "mm\"},{\"description\":\"round corner cube prism\",\"shape\":\"round_corner_cu"
    "be_prism\",\"diameter\":0.05,\"name\":\"Corner Cube Prism 50 "
    "mm\",\"offset\":0.0}]}"
};

// Details about the control object reference file
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE = {
    /* name        */ "riegl.control_object_reference_file",
    /* title       */ "Control Object Reference file",
    /* description */ "Details about the control object reference file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about the control object reference "
    "file\",\"properties\":{\"reference_file\":{\"description\":\"Reference to a "
    "control object file\",\"properties\":{\"file_uuid\":{\"description\":\"Control"
    " object file's Universally Unique Identifier (RFC "
    "4122)\",\"type\":\"string\"},\"file_path\":{\"description\":\"Path of the "
    "control object file relative to referring file\",\"type\":\"string\"}},\"req"
    "uired\":[\"file_uuid\",\"file_path\"],\"type\":\"object\"}},\"title\":\"Control "
    "Object Reference file\",\"$schema\":\"http://json-schema.org/draft-04/sche"
    "ma#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"reference_file\":{\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b4213\","
    "\"file_path\":\"../../../10_CONTROL_OBJECTS/ControlPoints.cpx\"}}"
};

// Detection probability as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_DETECTION_PROBABILITY = {
    /* name        */ "riegl.detection_probability",
    /* title       */ "Detection Probability",
    /* description */ "Detection probability as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Detection probability as a function of "
    "amplitude\",\"properties\":{\"amplitude\":{\"description\":\"Amplitude [dB]\",\""
    "items\":{\"type\":\"number\"},\"type\":\"array\"},\"detection_probability\":{\"des"
    "cription\":\"Detection probability "
    "[0..1]\",\"items\":{\"type\":\"number\"},\"type\":\"array\"}},\"title\":\"Detection "
    "Probability\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type"
    "\":\"object\",\"required\":[\"amplitude\",\"detection_probability\"]}"
    ,
    /* example: */
    "{\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0],\"detection"
    "_probability\":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]}"
};

// Details about the device used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICE = {
    /* name        */ "riegl.device",
    /* title       */ "Device Information",
    /* description */ "Details about the device used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about the device used to acquire the point "
    "cloud\",\"properties\":{\"channel_text\":{\"description\":\"Optional channel "
    "description (e.g. 'Green Channel' for multi-channel "
    "devices)\",\"type\":\"string\"},\"channel_number\":{\"description\":\"Laser "
    "channel number (not defined or 0: single channel device)\",\"minimum\":0,"
    "\"exclusiveMinimum\":false,\"type\":\"integer\"},\"device_build\":{\"descriptio"
    "n\":\"Device build "
    "variant\",\"type\":\"string\"},\"device_type\":{\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\",\"type\":\"string\"},\"device_name\":{\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\",\"type\":\"string\"},\"serial_number\":{\"description\":\"Device "
    "serial number (e.g. S2221234)\",\"type\":\"string\"}},\"title\":\"Device Infor"
    "mation\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"ob"
    "ject\",\"required\":[\"device_type\",\"serial_number\"]}"
    ,
    /* example: */
    "{\"channel_text\":\"\",\"channel_number\":0,\"device_build\":\"\",\"device_type\":"
    "\"VZ-400i\",\"device_name\":\"Scanner 1\",\"serial_number\":\"S2221234\"}"
};

// Scanner device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY = {
    /* name        */ "riegl.device_geometry",
    /* title       */ "Device Geometry",
    /* description */ "Scanner device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Scanner device geometry "
    "details\",\"properties\":{\"amu\":{\"description\":\"Angle Measurement "
    "Unit\",\"properties\":{\"lineCC\":{\"description\":\"Line Circle Count (number"
    " of LSBs per full rotation about line axis)\",\"minimum\":0,\"exclusiveMin"
    "imum\":false,\"type\":\"number\"},\"frameCC\":{\"description\":\"Frame Circle "
    "Count (number of LSBs per full rotation about frame axis)\",\"minimum\":0"
    ",\"exclusiveMinimum\":false,\"type\":\"number\"}},\"type\":\"object\"},\"secondar"
    "y\":{\"description\":\"Additional device geometry structure "
    "(optional)\",\"properties\":{\"ID\":{\"description\":\"Structure identifier\",\""
    "items\":{\"type\":\"integer\"},\"minItems\":2,\"maxItems\":2,\"type\":\"array\"},\"c"
    "ontent\":{\"description\":\"Internal calibration values\",\"items\":{\"type\":\""
    "number\"},\"type\":\"array\"}},\"required\":[\"ID\",\"content\"],\"type\":\"object\"}"
    ",\"primary\":{\"description\":\"Primary device geometry structure "
    "(mandatory)\",\"properties\":{\"ID\":{\"description\":\"Structure identifier\","
    "\"items\":{\"type\":\"integer\"},\"minItems\":2,\"maxItems\":2,\"type\":\"array\"},\""
    "content\":{\"description\":\"Internal calibration values\",\"items\":{\"type\":"
    "\"number\"},\"type\":\"array\"}},\"required\":[\"ID\",\"content\"],\"type\":\"object\""
    "}},\"title\":\"Device Geometry\",\"$schema\":\"http://json-schema.org/draft-0"
    "4/schema#\",\"type\":\"object\",\"required\":[\"primary\"]}"
    ,
    /* example: */
    "{\"amu\":{\"lineCC\":124000,\"frameCC\":124000},\"secondary\":{\"ID\":[91,0],\"co"
    "ntent\":[0]},\"primary\":{\"ID\":[4,0],\"content\":[0]}}"
};

// Scanner passive channel device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL = {
    /* name        */ "riegl.device_geometry_passive_channel",
    /* title       */ "Device Geometry Passive Channel",
    /* description */ "Scanner passive channel device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Scanner passive channel device geometry "
    "details\",\"properties\":{\"primary\":{\"description\":\"Primary device "
    "geometry structure "
    "(mandatory)\",\"properties\":{\"ID\":{\"description\":\"Structure identifier\","
    "\"items\":{\"type\":\"integer\"},\"minItems\":2,\"maxItems\":2,\"type\":\"array\"},\""
    "content\":{\"description\":\"Internal calibration values\",\"items\":{\"type\":"
    "\"number\"},\"type\":\"array\"}},\"required\":[\"ID\",\"content\"],\"type\":\"object\""
    "}},\"title\":\"Device Geometry Passive Channel\",\"$schema\":\"http://json-sc"
    "hema.org/draft-04/schema#\",\"type\":\"object\",\"required\":[\"primary\"]}"
    ,
    /* example: */
    "{\"primary\":{\"ID\":[143,0],\"content\":[0]}}"
};

// Limits of the measured values output by the device
const MetaDataItemInfo RDB_RIEGL_DEVICE_OUTPUT_LIMITS = {
    /* name        */ "riegl.device_output_limits",
    /* title       */ "Device Output Limits",
    /* description */ "Limits of the measured values output by the device",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Limits of the measured values output by the device. "
    "The limits depend on the device type, measurement program and/or scan "
    "pattern.\",\"properties\":{\"reflectance_minimum\":{\"description\":\"Minimum "
    "possible reflectance in "
    "dB.\",\"type\":\"number\"},\"deviation_maximum\":{\"description\":\"Maximum "
    "possible pulse shape deviation.\",\"type\":\"number\"},\"deviation_minimum\":"
    "{\"description\":\"Minimum possible pulse shape deviation.\",\"type\":\"numbe"
    "r\"},\"amplitude_maximum\":{\"description\":\"Maximum possible amplitude in "
    "dB.\",\"type\":\"number\"},\"background_radiation_maximum\":{\"description\":\"M"
    "aximum possible background radiation.\",\"type\":\"number\"},\"mta_zone_coun"
    "t_maximum\":{\"description\":\"Maximum number of MTA "
    "zones.\",\"type\":\"number\"},\"amplitude_minimum\":{\"description\":\"Minimum "
    "possible amplitude in "
    "dB.\",\"type\":\"number\"},\"range_maximum\":{\"description\":\"Maximum possible"
    " range in "
    "meters.\",\"type\":\"number\"},\"echo_count_maximum\":{\"description\":\"Maximum"
    " number of echoes a laser shot can have.\",\"type\":\"number\"},\"background"
    "_radiation_minimum\":{\"description\":\"Minimum possible background radiat"
    "ion.\",\"type\":\"number\"},\"reflectance_maximum\":{\"description\":\"Maximum "
    "possible reflectance in "
    "dB.\",\"type\":\"number\"},\"range_minimum\":{\"description\":\"Minimum possible"
    " range in meters.\",\"type\":\"number\"}},\"title\":\"Device Output Limits\",\"$"
    "schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"amplitude_minimum\":0.0,\"background_radiation_minimum\":0,\"deviation_m"
    "inimum\":-1,\"amplitude_maximum\":100.0,\"range_maximum\":10000.0,\"backgrou"
    "nd_radiation_maximum\":0,\"deviation_maximum\":32767,\"mta_zone_count_maxi"
    "mum\":7,\"reflectance_minimum\":-100.0,\"reflectance_maximum\":100.0,\"range"
    "_minimum\":2.9}"
};

// Details about the devices used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICES = {
    /* name        */ "riegl.devices",
    /* title       */ "Devices Information",
    /* description */ "Details about the devices used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about the devices used to acquire the point "
    "cloud (e.g. when merging point clouds of different "
    "devices)\",\"title\":\"Devices Information\",\"$schema\":\"http://json-schema."
    "org/draft-04/schema#\",\"items\":{\"properties\":{\"channel_text\":{\"descript"
    "ion\":\"Optional channel description (e.g. 'Green Channel' for "
    "multi-channel "
    "devices)\",\"type\":\"string\"},\"channel_number\":{\"description\":\"Laser "
    "channel number (not defined or 0: single channel device)\",\"minimum\":0,"
    "\"exclusiveMinimum\":false,\"type\":\"integer\"},\"device_build\":{\"descriptio"
    "n\":\"Device build "
    "variant\",\"type\":\"string\"},\"signed\":{\"description\":\"Flag that is set "
    "when the original 'riegl.device' entry in the source file was "
    "correctly "
    "signed.\",\"type\":\"boolean\"},\"device_type\":{\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\",\"type\":\"string\"},\"device_name\":{\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\",\"type\":\"string\"},\"serial_number\":{\"description\":\"Device "
    "serial number (e.g. S2221234)\",\"type\":\"string\"}},\"required\":[\"device_t"
    "ype\",\"serial_number\"],\"type\":\"object\"},\"type\":\"array\"}"
    ,
    /* example: */
    "[{\"channel_text\":\"\",\"channel_number\":0,\"device_build\":\"\",\"signed\":fals"
    "e,\"device_type\":\"VZ-400i\",\"device_name\":\"Scanner 1\",\"serial_number\":\"S"
    "2221234\"},{\"channel_text\":\"\",\"channel_number\":1,\"device_build\":\"\",\"sig"
    "ned\":true,\"device_type\":\"VQ-1560i-DW\",\"device_name\":\"Scanner 2\",\"seria"
    "l_number\":\"S2222680\"},{\"channel_text\":\"\",\"channel_number\":2,\"device_bu"
    "ild\":\"\",\"signed\":true,\"device_type\":\"VQ-1560i-DW\",\"device_name\":\"Scann"
    "er 3\",\"serial_number\":\"S2222680\"}]"
};

// Dyntrig
const MetaDataItemInfo RDB_RIEGL_DYNTRIG = {
    /* name        */ "riegl.dyntrig",
    /* title       */ "Dyntrig",
    /* description */ "Dyntrig",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Dyntrig\",\"properties\":{\"scale\":{\"description\":\"Scale "
    "in units of dB, for calculation of line: line number N=(amplitude-offs"
    "et)/scale\",\"type\":\"number\"},\"pre\":{\"description\":\"Dyntrig pre "
    "values\",\"properties\":{\"nc\":{\"description\":\"Number of entries\",\"minimum"
    "\":0,\"maximum\":255,\"type\":\"integer\"},\"a\":{\"description\":\"...\",\"items\":{"
    "\"type\":\"number\"},\"minItems\":1,\"maxItems\":2080,\"type\":\"array\"}},\"requir"
    "ed\":[\"nc\",\"a\"],\"type\":\"object\"},\"post\":{\"description\":\"Dyntrig post "
    "values\",\"properties\":{\"nc\":{\"description\":\"Number of entries\",\"minimum"
    "\":0,\"maximum\":255,\"type\":\"integer\"},\"a\":{\"description\":\"...\",\"items\":{"
    "\"type\":\"number\"},\"minItems\":1,\"maxItems\":2080,\"type\":\"array\"}},\"requir"
    "ed\":[\"nc\",\"a\"],\"type\":\"object\"},\"tab\":{\"description\":\"...\",\"items\":{\"d"
    "escription\":\"...\",\"properties\":{\"thra1\":{\"description\":\"Post-trigger "
    "threshold in units of "
    "dB\",\"type\":\"number\"},\"dec1\":{\"description\":\"Decay of post-trigger "
    "threshold after del1 in units of "
    "dB/m\",\"type\":\"number\"},\"del2\":{\"description\":\"Length of constant "
    "pre-trigger threshold elevation in units of "
    "m\",\"type\":\"number\"},\"del1\":{\"description\":\"Length of constant "
    "post-trigger threshold elevation in units of "
    "m\",\"type\":\"number\"},\"thra2\":{\"description\":\"Pre-trigger threshold in "
    "units of dB\",\"type\":\"number\"},\"dec2\":{\"description\":\"Rise of "
    "pre-trigger threshold after del2 in units of dB/m\",\"type\":\"number\"}},\""
    "required\":[\"thra1\",\"del1\",\"dec1\",\"thra2\",\"del2\",\"dec2\"],\"type\":\"object"
    "\"},\"minItems\":1,\"maxItems\":128,\"type\":\"array\"},\"offset\":{\"description\""
    ":\"Offset in units of dB, for calculation of line\",\"type\":\"number\"}},\"t"
    "itle\":\"Dyntrig\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"scale\":1.0,\"pre\":{\"nc\":128,\"a\":[78,86,126,134,31]},\"post\":{\"nc\":128,"
    "\"a\":[78,86,126,134,31]},\"tab\":[{\"thra1\":0.0,\"dec1\":0.0,\"del2\":0.0,\"del"
    "1\":0.0,\"thra2\":0.0,\"dec2\":0.0}],\"offset\":0.0}"
};

// Details about echo files
const MetaDataItemInfo RDB_RIEGL_ECHO_INFO = {
    /* name        */ "riegl.echo_info",
    /* title       */ "Echo Information",
    /* description */ "Details about echo files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about echo files\",\"properties\":{\"echo_file\":{\""
    "properties\":{\"file_uuid\":{\"description\":\"File's Universally Unique "
    "Identifier (RFC "
    "4122)\",\"type\":\"string\"},\"file_extension\":{\"description\":\"Echo file "
    "extension, without the leading dot\",\"type\":\"string\"}},\"required\":[\"fil"
    "e_extension\"],\"type\":\"object\"}},\"title\":\"Echo Information\",\"$schema\":\""
    "http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"required\":[\""
    "echo_file\"]}"
    ,
    /* example: */
    "{\"echo_file\":{\"file_uuid\":\"26a03615-67c0-4bea-8fe8-c577378fe661\",\"file"
    "_extension\":\"owp\"}}"
};

// Details for exponential decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_EXPONENTIAL_DECOMPOSITION = {
    /* name        */ "riegl.exponential_decomposition",
    /* title       */ "Exponential Decomposition",
    /* description */ "Details for exponential decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details for exponential decomposition of full waveform"
    " data\",\"additionalProperties\":false,\"title\":\"Exponential Decomposition"
    "\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\","
    "\"patternProperties\":{\"^[0-9]+$\":{\"description\":\"one field per channel,"
    " field name is channel index\",\"$ref\":\"#/definitions/channel\"}},\"defini"
    "tions\":{\"channel\":{\"properties\":{\"scale\":{\"description\":\"amplitude "
    "calibration\",\"type\":\"number\"},\"delay\":{\"description\":\"delay "
    "calibration in "
    "seconds\",\"type\":\"number\"},\"parameter\":{\"description\":\"parameters of "
    "the syswave exponential "
    "sum\",\"properties\":{\"gamma\":{\"description\":\"decay in 1/second\",\"items\":"
    "{\"type\":\"number\"},\"type\":\"array\"},\"A\":{\"description\":\"real part of "
    "amplitude factor in units of full-scale\",\"items\":{\"type\":\"number\"},\"ty"
    "pe\":\"array\"},\"omega\":{\"description\":\"angular frequency in Hz\",\"items\":"
    "{\"type\":\"number\"},\"type\":\"array\"},\"B\":{\"description\":\"imaginary part "
    "of amplitude factor in units of full-scale\",\"items\":{\"type\":\"number\"},"
    "\"type\":\"array\"}},\"required\":[\"A\",\"B\",\"gamma\",\"omega\"],\"type\":\"object\"}"
    ",\"a_lin\":{\"description\":\"relative linear amplitude range [0..1]\",\"excl"
    "usiveMaximum\":false,\"type\":\"number\",\"exclusiveMinimum\":false,\"maximum\""
    ":1,\"minimum\":0}},\"required\":[\"delay\",\"scale\",\"parameter\"],\"type\":\"obje"
    "ct\"}}}"
    ,
    /* example: */
    "{\"1\":{\"scale\":1.0,\"delay\":3.5e-09,\"parameter\":{\"gamma\":[-1094726528.0,"
    "-769562752.0,-848000064.0],\"A\":[0.9,0.3,-1.3],\"omega\":[352020896.0,364"
    "7927552.0,-1977987072.0],\"B\":[-3.9,0.0,-0.3]},\"a_lin\":0.9},\"0\":{\"scale"
    "\":1.0,\"delay\":3.783458418887631e-09,\"parameter\":{\"gamma\":[-1094726528."
    "0,-769562752.0,-848000064.0],\"A\":[0.9772450923919678,0.335433512926101"
    "7,-1.312678575515747],\"omega\":[352020896.0,3647927552.0,-1977987072.0]"
    ",\"B\":[-3.9813032150268555,0.08622030913829803,-0.3152860999107361]},\"a"
    "_lin\":0.27}}"
};

// Details for Gaussian decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_GAUSSIAN_DECOMPOSITION = {
    /* name        */ "riegl.gaussian_decomposition",
    /* title       */ "Gaussian Decomposition",
    /* description */ "Details for Gaussian decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"riegl.gaussian_decomposition contains information "
    "relevant for extracting calibrated amplitudes and calibrated ranges "
    "from a Gaussian decomposition of full waveform data. This information "
    "is contained in a table with five columns. Two columns are to be used "
    "as input: amplitude_lsb_low_power and amplitude_lsb_high_power. The "
    "other three columns provide the outputs. Amplitude_db gives the "
    "calibrated amplitude in the optical regime in decibels. The range "
    "offset columns provide additive range offsets, given in units of "
    "seconds, for each channel.\",\"properties\":{\"range_offset_sec_high_power"
    "\":{\"items\":{\"type\":\"number\"},\"type\":\"array\"},\"amplitude_lsb_high_power"
    "\":{\"items\":{\"type\":\"number\"},\"type\":\"array\"},\"range_offset_sec_low_pow"
    "er\":{\"items\":{\"type\":\"number\"},\"type\":\"array\"},\"amplitude_lsb_low_powe"
    "r\":{\"items\":{\"type\":\"number\"},\"type\":\"array\"},\"amplitude_db\":{\"items\":"
    "{\"type\":\"number\"},\"type\":\"array\"}},\"title\":\"Gaussian Decomposition\",\"$"
    "schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"req"
    "uired\":[\"amplitude_lsb_low_power\",\"amplitude_lsb_high_power\",\"amplitud"
    "e_db\",\"range_offset_sec_low_power\",\"range_offset_sec_high_power\"]}"
    ,
    /* example: */
    "{\"range_offset_sec_high_power\":[],\"amplitude_lsb_high_power\":[],\"range"
    "_offset_sec_low_power\":[],\"amplitude_lsb_low_power\":[],\"amplitude_db\":"
    "[]}"
};

// Point cloud georeferencing information
const MetaDataItemInfo RDB_RIEGL_GEO_TAG = {
    /* name        */ "riegl.geo_tag",
    /* title       */ "Geo Tag",
    /* description */ "Point cloud georeferencing information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Point cloud georeferencing "
    "information\",\"properties\":{\"crs\":{\"description\":\"Global Coordinate "
    "Reference System. Please note that only 3D Cartesian Coordinate "
    "Systems are allowed.\",\"properties\":{\"wkt\":{\"description\":\"\\\"Well-Known"
    " Text\\\" string, OGC WKT dialect (see http://www.opengeospatial.org/sta"
    "ndards/wkt-crs)\",\"type\":\"string\"},\"epsg\":{\"description\":\"EPSG "
    "code\",\"minimum\":0,\"type\":\"integer\"},\"name\":{\"description\":\"Coordinate "
    "reference system name\",\"type\":\"string\"}},\"type\":\"object\"},\"pose\":{\"des"
    "cription\":\"Coordinate Transformation Matrix to transform from File "
    "Coordinate System to Global Coordinate Reference System. 4x4 matrix "
    "stored as two dimensional array, row major order.\",\"items\":{\"descripti"
    "on\":\"rows\",\"items\":{\"description\":\"columns\",\"type\":\"number\"},\"minItems"
    "\":4,\"maxItems\":4,\"type\":\"array\"},\"minItems\":4,\"maxItems\":4,\"type\":\"arr"
    "ay\"}},\"title\":\"Geo Tag\",\"$schema\":\"http://json-schema.org/draft-04/sch"
    "ema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"crs\":{\"wkt\":\"GEOCCS[\\\"WGS84 Geocentric\\\",DATUM[\\\"WGS84\\\",SPHEROID[\\\""
    "WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AUTHOR"
    "ITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000000000000,AUTHOR"
    "ITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Meter\\\",1.00000000000000000000,AUTHORIT"
    "Y[\\\"EPSG\\\",\\\"9001\\\"]],AXIS[\\\"X\\\",OTHER],AXIS[\\\"Y\\\",EAST],AXIS[\\\"Z\\\",NO"
    "RTH],AUTHORITY[\\\"EPSG\\\",\\\"4978\\\"]]\",\"epsg\":4978,\"name\":\"WGS84 Geocentr"
    "ic\"},\"pose\":[[-0.269827776749716,-0.723017716139738,0.635954678449952,"
    "4063882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847"
    ",1138787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196"
    "],[0.0,0.0,0.0,1.0]]}"
};

// Geometric scale factor applied to point coordinates
const MetaDataItemInfo RDB_RIEGL_GEOMETRIC_SCALE_FACTOR = {
    /* name        */ "riegl.geometric_scale_factor",
    /* title       */ "Geometric Scale Factor",
    /* description */ "Geometric scale factor applied to point coordinates",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Geometric scale factor applied to point coordinates\",\""
    "exclusiveMinimum\":true,\"minimum\":0,\"$schema\":\"http://json-schema.org/d"
    "raft-04/schema#\",\"type\":\"number\"}"
    ,
    /* example: */
    "1.0"
};

// Parameters used for georeferencing of the point cloud
const MetaDataItemInfo RDB_RIEGL_GEOREFERENCING_PARAMETERS = {
    /* name        */ "riegl.georeferencing_parameters",
    /* title       */ "Georeferencing Parameters",
    /* description */ "Parameters used for georeferencing of the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Parameters used for georeferencing of the point "
    "cloud\",\"properties\":{\"socs_to_body_matrix\":{\"description\":\"Coordinate "
    "Transformation Matrix to transform from Scanner's Own Coordinate "
    "System to Body Coordinate System. 4x4 matrix stored as two dimensional"
    " array, row major order.\",\"items\":{\"description\":\"rows\",\"items\":{\"desc"
    "ription\":\"columns\",\"type\":\"number\"},\"minItems\":4,\"maxItems\":4,\"type\":\""
    "array\"},\"minItems\":4,\"maxItems\":4,\"type\":\"array\"},\"trajectory_file\":{\""
    "description\":\"Trajectory data used for georeferencing of the point "
    "cloud\",\"properties\":{\"file_uuid\":{\"description\":\"File's Universally "
    "Unique Identifier (RFC "
    "4122)\",\"type\":\"string\"},\"file_extension\":{\"description\":\"Trajectory "
    "file extension, without the leading dot\",\"type\":\"string\"}},\"required\":"
    "[\"file_extension\"],\"type\":\"object\"},\"socs_to_rocs_matrix\":{\"descriptio"
    "n\":\"Coordinate Transformation Matrix to transform from Scanner's Own "
    "Coordinate System to Record Coordinate System. 4x4 matrix stored as "
    "two dimensional array, row major order.\",\"items\":{\"description\":\"rows\""
    ",\"items\":{\"description\":\"columns\",\"type\":\"number\"},\"minItems\":4,\"maxIt"
    "ems\":4,\"type\":\"array\"},\"minItems\":4,\"maxItems\":4,\"type\":\"array\"},\"traj"
    "ectory_offsets\":{\"description\":\"Correction offsets applied to the "
    "trajectory data\",\"properties\":{\"offset_pitch\":{\"description\":\"[deg]\",\""
    "type\":\"number\"},\"offset_roll\":{\"description\":\"[deg]\",\"type\":\"number\"},"
    "\"offset_north\":{\"description\":\"[m]\",\"type\":\"number\"},\"version\":{\"descr"
    "iption\":\"Meaning of offset values and how to apply them; version 0: "
    "Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), "
    "version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch"
    ")*Rx(offset_roll)\",\"type\":\"integer\"},\"offset_yaw\":{\"description\":\"[deg"
    "]\",\"type\":\"number\"},\"offset_time\":{\"description\":\"[s]\",\"type\":\"number\""
    "},\"offset_height\":{\"description\":\"[m]\",\"type\":\"number\"},\"offset_east\":"
    "{\"description\":\"[m]\",\"type\":\"number\"}},\"type\":\"object\"},\"body_coordina"
    "te_system_type\":{\"description\":\"BODY coordinate frame (NED: "
    "North-East-Down, ENU: East-North-Up), default: "
    "NED\",\"enum\":[\"NED\",\"ENU\"],\"type\":\"string\"}},\"title\":\"Georeferencing Pa"
    "rameters\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\""
    "object\"}"
    ,
    /* example: */
    "{\"socs_to_body_matrix\":[[-0.269827776749716,-0.723017716139738,0.63595"
    "4678449952,0.0],[0.962908599449764,-0.20260517250352,0.178208229833847"
    ",0.0],[0.0,0.660451759194338,0.7508684796801,0.0],[0.0,0.0,0.0,1.0]],\""
    "trajectory_file\":{\"file_uuid\":\"93a03615-66c0-4bea-8ff8-c577378fe660\",\""
    "file_extension\":\"pofx\"},\"trajectory_offsets\":{\"offset_pitch\":0.01,\"off"
    "set_roll\":0.03,\"offset_north\":0.07,\"version\":0,\"offset_yaw\":-0.45,\"off"
    "set_time\":18.007,\"offset_height\":-0.2,\"offset_east\":0.15},\"body_coordi"
    "nate_system_type\":\"NED\"}"
};

// Map of item names
const MetaDataItemInfo RDB_RIEGL_ITEM_NAMES = {
    /* name        */ "riegl.item_names",
    /* title       */ "Item Names",
    /* description */ "Map of item names",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Map of item "
    "names\",\"additionalProperties\":false,\"title\":\"Item Names\",\"$schema\":\"ht"
    "tp://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"patternPropert"
    "ies\":{\"^-?[0-9]+$\":{\"description\":\"One field per item, field name is "
    "item id, field value is item name\",\"type\":\"string\"}}}"
    ,
    /* example: */
    "{\"1\":\"Name of item with id 1\",\"-1\":\"Name of item with id "
    "-1\",\"47\":\"Name of item with id 47\",\"2\":\"Name of item with id 2\"}"
};

// License keys for software features
const MetaDataItemInfo RDB_RIEGL_LICENSES = {
    /* name        */ "riegl.licenses",
    /* title       */ "Software License Keys",
    /* description */ "License keys for software features",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"License keys for software "
    "features\",\"additionalProperties\":false,\"title\":\"Software License Keys\""
    ",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\""
    "patternProperties\":{\"^.*$\":{\"description\":\"Each field of the object "
    "represents a feature and holds a list of license keys, where the field"
    " name is the feature name.\",\"items\":{\"description\":\"License key "
    "(example: '46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73')\",\"type\":\"string\"},\"minItems\":1,\"type\":\"array\"}}}"
    ,
    /* example: */
    "{\"Georeferencing\":[\"46AE032A - 39882AC4 - 9EC0A184 - 6F163D73\"],\"Full "
    "Waveform Analysis Topography\":[\"0FD5FF07 - 011A1255 - 9F76CACA - "
    "8D2ED557\"],\"Full Waveform Analysis Topography with GPU "
    "support\":[\"8AB44126 - 23B92250 - 16E2689F - 34EF7E7B\"],\"MTA "
    "resolution\":[\"468E020A - 39A922E4 - B681A184 - 673E3D72\"]}"
};

// Parameters for MTA processing
const MetaDataItemInfo RDB_RIEGL_MTA_SETTINGS = {
    /* name        */ "riegl.mta_settings",
    /* title       */ "MTA Settings",
    /* description */ "Parameters for MTA processing",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Parameters for MTA "
    "processing\",\"properties\":{\"zone_count\":{\"description\":\"Maximum number "
    "of MTA zones.\",\"minimum\":0,\"maximum\":255,\"type\":\"integer\"},\"modulation"
    "_depth\":{\"description\":\"Depth of pulse position modulation in meter.\","
    "\"minimum\":0,\"type\":\"number\"},\"zone_width\":{\"description\":\"Width of a "
    "MTA zone in meter.\",\"minimum\":0,\"type\":\"number\"}},\"title\":\"MTA Setting"
    "s\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\""
    "}"
    ,
    /* example: */
    "{\"zone_count\":23,\"modulation_depth\":9.368514,\"zone_width\":149.896225}"
};

// Lookup table for range correction based on raw range
const MetaDataItemInfo RDB_RIEGL_NEAR_RANGE_CORRECTION = {
    /* name        */ "riegl.near_range_correction",
    /* title       */ "Near Range Correction Table",
    /* description */ "Lookup table for range correction based on raw range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Lookup table for range correction based on raw "
    "range\",\"properties\":{\"delta\":{\"description\":\"Delta between table "
    "entries [m], first entry is at range = 0 "
    "m\",\"type\":\"number\"},\"content\":{\"description\":\"Correction value [m] to "
    "be added to the raw range\",\"items\":{\"type\":\"number\"},\"minItems\":1,\"max"
    "Items\":2000,\"type\":\"array\"}},\"title\":\"Near Range Correction Table\",\"$s"
    "chema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"requ"
    "ired\":[\"delta\",\"content\"]}"
    ,
    /* example: */
    "{\"delta\":0.512,\"content\":[0.0]}"
};

// Standard deviation for range and amplitude as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_NOISE_ESTIMATES = {
    /* name        */ "riegl.noise_estimates",
    /* title       */ "Noise Estimates",
    /* description */ "Standard deviation for range and amplitude as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Standard deviation for range and amplitude as a "
    "function of "
    "amplitude\",\"properties\":{\"amplitude\":{\"description\":\"Amplitude [dB]\",\""
    "items\":{\"type\":\"number\"},\"type\":\"array\"},\"amplitude_sigma\":{\"descripti"
    "on\":\"Sigma amplitude [dB]\",\"items\":{\"type\":\"number\"},\"type\":\"array\"},\""
    "range_sigma\":{\"description\":\"Sigma range "
    "[m]\",\"items\":{\"type\":\"number\"},\"type\":\"array\"}},\"title\":\"Noise Estimat"
    "es\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object"
    "\",\"required\":[\"amplitude\",\"range_sigma\",\"amplitude_sigma\"]}"
    ,
    /* example: */
    "{\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0],\"amplitude"
    "_sigma\":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0.432,0.39,0.3"
    "54],\"range_sigma\":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.0"
    "18,0.016,0.014]}"
};

// Notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_NOTCH_FILTER = {
    /* name        */ "riegl.notch_filter",
    /* title       */ "Notch Filter",
    /* description */ "Notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Notch filter parameters for window glass "
    "echoes\",\"properties\":{\"range_maximum\":{\"description\":\"Maximum range "
    "[m]\",\"type\":\"number\"},\"amplitude_maximum\":{\"description\":\"Maximum "
    "amplitude [dB]\",\"minimum\":0,\"type\":\"number\"},\"range_minimum\":{\"descrip"
    "tion\":\"Minimum range [m]\",\"type\":\"number\"}},\"title\":\"Notch Filter\",\"$s"
    "chema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"requ"
    "ired\":[\"range_minimum\",\"range_maximum\",\"amplitude_maximum\"]}"
    ,
    /* example: */
    "{\"range_maximum\":0.2,\"amplitude_maximum\":18.0,\"range_minimum\":-0.5}"
};

// Details about the pixels contained in the file
const MetaDataItemInfo RDB_RIEGL_PIXEL_INFO = {
    /* name        */ "riegl.pixel_info",
    /* title       */ "Pixel Information",
    /* description */ "Details about the pixels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about the pixels contained in the "
    "file\",\"properties\":{\"size_llcs\":{\"description\":\"Size of pixels in a "
    "locally levelled cartesian coordinate system (xy). This is only used "
    "for pixels based on a map projection.\",\"$ref\":\"#/definitions/pixel_siz"
    "e\"},\"size\":{\"description\":\"Size of pixels in file coordinate "
    "system.\",\"$ref\":\"#/definitions/pixel_size\"}},\"title\":\"Pixel Informatio"
    "n\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\""
    ",\"required\":[\"size\"],\"definitions\":{\"pixel_size\":{\"description\":\"Size "
    "of pixels.\",\"items\":{\"description\":\"Length of pixel edge [m].\",\"minimu"
    "m\":0,\"type\":\"number\"},\"minItems\":2,\"maxItems\":2,\"type\":\"array\"}}}"
    ,
    /* example: */
    "{\"size_llcs\":[0.5156575252891171,0.5130835356683303],\"size\":[0.5971642"
    "834779395,0.5971642834779395]}"
};

// Details about the plane patch matching process
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_MATCHING = {
    /* name        */ "riegl.plane_patch_matching",
    /* title       */ "Plane Patch Matching",
    /* description */ "Details about the plane patch matching process",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about the plane patch matching process\",\"prope"
    "rties\":{\"plane_patch_file_one\":{\"description\":\"Reference to the plane "
    "patch file one\",\"$ref\":\"#/definitions/file_reference\"},\"plane_patch_fi"
    "le_two\":{\"description\":\"Reference to the plane patch file "
    "two\",\"$ref\":\"#/definitions/file_reference\"}},\"title\":\"Plane Patch Matc"
    "hing\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"obje"
    "ct\",\"required\":[\"plane_patch_file_one\",\"plane_patch_file_two\"],\"defini"
    "tions\":{\"file_reference\":{\"description\":\"Reference to a plane patch "
    "file\",\"properties\":{\"file_uuid\":{\"description\":\"Plane patch file's "
    "Universally Unique Identifier (RFC "
    "4122)\",\"type\":\"string\"},\"file_path\":{\"description\":\"Path of the plane "
    "patch file relative to the match file\",\"type\":\"string\"}},\"required\":[\""
    "file_uuid\",\"file_path\"],\"type\":\"object\"}}}"
    ,
    /* example: */
    "{\"plane_patch_file_one\":{\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b"
    "4213\",\"file_path\":\"Record009_Line001/191025_121410_Scanner_1.ptch\"},\"p"
    "lane_patch_file_two\":{\"file_uuid\":\"fa47d509-a64e-49ce-8b14-ff3130fbefa"
    "9\",\"file_path\":\"project.ptch\"}}"
};

// Statistics about plane patches found by plane patch extractor
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_STATISTICS = {
    /* name        */ "riegl.plane_patch_statistics",
    /* title       */ "Plane Patch Statistics",
    /* description */ "Statistics about plane patches found by plane patch extractor",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Statistics about plane patches found by plane patch "
    "extractor\",\"properties\":{\"total_horizontal_area\":{\"description\":\"sum "
    "of all plane patch areas projected to horizontal plane "
    "[m\\u00b2]\",\"type\":\"number\"},\"total_area\":{\"description\":\"sum of all "
    "plane patch areas [m\\u00b2]\",\"type\":\"number\"}},\"title\":\"Plane Patch St"
    "atistics\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\""
    "object\"}"
    ,
    /* example: */
    "{\"total_horizontal_area\":13954.601,\"total_area\":14007.965}"
};

// Settings and classes for plane slope classification
const MetaDataItemInfo RDB_RIEGL_PLANE_SLOPE_CLASS_INFO = {
    /* name        */ "riegl.plane_slope_class_info",
    /* title       */ "Plane Slope Class Info",
    /* description */ "Settings and classes for plane slope classification",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Settings and classes for plane slope "
    "classification\",\"properties\":{\"classes\":{\"description\":\"Class "
    "definition table\",\"additionalProperties\":false,\"patternProperties\":{\"^"
    "[0-9]+$\":{\"description\":\"one field per class, field name is class "
    "number, field value is class name\",\"type\":\"string\"}},\"type\":\"object\"},"
    "\"settings\":{\"description\":\"Classification settings, details see "
    "documentation of rdbplanes\",\"oneOf\":[{\"$ref\":\"#/definitions/method-1\"}"
    ",{\"$ref\":\"#/definitions/method-2\"}],\"type\":\"object\"}},\"title\":\"Plane "
    "Slope Class Info\",\"$schema\":\"http://json-schema.org/draft-04/schema#\","
    "\"type\":\"object\",\"required\":[\"settings\",\"classes\"],\"definitions\":{\"meth"
    "od-2\":{\"description\":\"Classification method "
    "2\",\"properties\":{\"plane_classification_method\":{\"description\":\"method "
    "ID (=2)\",\"minimum\":2,\"maximum\":2,\"type\":\"integer\"},\"sloping_plane_clas"
    "ses_maximum_angle\":{\"description\":\"maximum inclination angle of "
    "sloping plane patches [deg]\",\"minimum\":-360.0,\"maximum\":360.0,\"type\":\""
    "number\"},\"sloping_plane_classes_minimum_angle\":{\"description\":\"minimum"
    " inclination angle of sloping plane patches [deg]\",\"minimum\":-360.0,\"m"
    "aximum\":360.0,\"type\":\"number\"}},\"required\":[\"plane_classification_meth"
    "od\",\"sloping_plane_classes_minimum_angle\",\"sloping_plane_classes_maxim"
    "um_angle\"],\"type\":\"object\"},\"method-1\":{\"description\":\"Classification "
    "method 1\",\"properties\":{\"maximum_inclination_angle_horizontal\":{\"descr"
    "iption\":\"maximum inclination angle of horizontal plane patches [deg]\","
    "\"minimum\":-360.0,\"maximum\":360.0,\"type\":\"number\"},\"plane_classificatio"
    "n_method\":{\"description\":\"method ID (=1)\",\"minimum\":1,\"maximum\":1,\"typ"
    "e\":\"integer\"}},\"required\":[\"plane_classification_method\",\"maximum_incl"
    "ination_angle_horizontal\"],\"type\":\"object\"}}}"
    ,
    /* example: */
    "{\"classes\":{\"6\":\"vertical, pointing east\",\"11\":\"sloping, pointing down"
    " and south\",\"2\":\"sloping, pointing up and east\",\"3\":\"sloping, pointing"
    " up and south\",\"4\":\"sloping, pointing up and north\",\"13\":\"sloping, "
    "pointing down and west\",\"9\":\"vertical, pointing west\",\"7\":\"vertical, "
    "pointing south\",\"5\":\"sloping, pointing up and west\",\"14\":\"horizontal, "
    "pointing down\",\"1\":\"horizontal, pointing up\",\"10\":\"sloping, pointing "
    "down and east\",\"8\":\"vertical, pointing north\",\"12\":\"sloping, pointing "
    "down and north\"},\"settings\":{\"plane_classification_method\":2,\"sloping_"
    "plane_classes_maximum_angle\":70.0,\"sloping_plane_classes_minimum_angle"
    "\":10.0}}"
};

// Grouping and sorting of point attributes for visualization purposes
const MetaDataItemInfo RDB_RIEGL_POINT_ATTRIBUTE_GROUPS = {
    /* name        */ "riegl.point_attribute_groups",
    /* title       */ "Point Attribute Groups",
    /* description */ "Grouping and sorting of point attributes for visualization purposes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Grouping and sorting of point attributes for "
    "visualization purposes\",\"additionalProperties\":false,\"title\":\"Point "
    "Attribute Groups\",\"$schema\":\"http://json-schema.org/draft-04/schema#\","
    "\"type\":\"object\",\"patternProperties\":{\"^.*$\":{\"description\":\"Each field"
    " of the object represents a point attribute group and holds a list of "
    "point attributes, where the field name is the group "
    "name.\",\"items\":{\"description\":\"Point attribute full name or name "
    "pattern (perl regular expression "
    "syntax)\",\"type\":\"string\"},\"minItems\":1,\"type\":\"array\"}}}"
    ,
    /* example: */
    "{\"Primary Attributes\":[\"riegl.reflectance\",\"riegl.amplitude\",\"riegl.de"
    "viation\"],\"Time\":[\"riegl.timestamp\"],\"Secondary "
    "Attributes\":[\"riegl.mirror_facet\",\"riegl.waveform_available\"],\"Other A"
    "ttributes\":[\"riegl.selected\",\"riegl.visible\"],\"Coordinates/Vectors\":[\""
    "riegl.xyz\",\"riegl.range\",\"riegl.theta\",\"riegl.phi\"]}"
};

// Details about point cloud files
const MetaDataItemInfo RDB_RIEGL_POINTCLOUD_INFO = {
    /* name        */ "riegl.pointcloud_info",
    /* title       */ "Point Cloud Information",
    /* description */ "Details about point cloud files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about point cloud "
    "files\",\"properties\":{\"project\":{\"description\":\"Project name\",\"type\":\"s"
    "tring\"},\"comments\":{\"description\":\"Comments\",\"type\":\"string\"},\"field_o"
    "f_application\":{\"description\":\"Field of application\",\"enum\":[\"unknown\""
    ",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"],\"type\":\"string\"}},\"t"
    "itle\":\"Point Cloud Information\",\"$schema\":\"http://json-schema.org/draf"
    "t-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"project\":\"Campaign 4\",\"comments\":\"Line "
    "3\",\"field_of_application\":\"ALS\"}"
};

// Estimated position and orientation information
const MetaDataItemInfo RDB_RIEGL_POSE_ESTIMATION = {
    /* name        */ "riegl.pose_estimation",
    /* title       */ "Pose Estimation",
    /* description */ "Estimated position and orientation information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Estimated position and orientation information as "
    "measured by GNSS, IMU or inclination sensors\",\"properties\":{\"barometri"
    "c_height_amsl\":{\"description\":\"Altitude determined based on the "
    "atmospheric pressure according to the standard atmosphere laws "
    "[m].\",\"type\":\"number\"},\"orientation\":{\"description\":\"Orientation "
    "values and orientation accuracies, measured with IMU or inclination "
    "sensors.\",\"properties\":{\"yaw_accuracy\":{\"description\":\"Yaw angle "
    "accuracy [deg]\",\"minimum\":0,\"exclusiveMinimum\":true,\"type\":\"number\"},\""
    "roll_accuracy\":{\"description\":\"Roll angle accuracy [deg]\",\"minimum\":0,"
    "\"exclusiveMinimum\":true,\"type\":\"number\"},\"pitch\":{\"description\":\"Pitch"
    " angle about scanner Y-axis [deg]\",\"minimum\":-360,\"maximum\":360,\"type\""
    ":\"number\"},\"pitch_accuracy\":{\"description\":\"Pitch angle accuracy [deg]"
    "\",\"minimum\":0,\"exclusiveMinimum\":true,\"type\":\"number\"},\"roll\":{\"descri"
    "ption\":\"Roll angle about scanner X-axis [deg]\",\"minimum\":-360,\"maximum"
    "\":360,\"type\":\"number\"},\"yaw\":{\"description\":\"Yaw angle about scanner "
    "Z-axis [deg]\",\"minimum\":-360,\"maximum\":360,\"type\":\"number\"}},\"required"
    "\":[\"roll\",\"pitch\",\"yaw\",\"roll_accuracy\",\"pitch_accuracy\",\"yaw_accuracy"
    "\"],\"type\":\"object\"},\"position\":{\"description\":\"Position coordinates "
    "and position accuracy values as measured by GNSS in the specified "
    "Coordinate Reference System "
    "(CRS)\",\"properties\":{\"coordinate_2\":{\"description\":\"Coordinate 2 as "
    "defined by axis 2 of the specified CRS (e.g., Y, Longitude)\",\"type\":\"n"
    "umber\"},\"horizontal_accuracy\":{\"description\":\"Horizontal accuracy [m]\""
    ",\"minimum\":0,\"exclusiveMinimum\":true,\"type\":\"number\"},\"coordinate_1\":{"
    "\"description\":\"Coordinate 1 as defined by axis 1 of the specified CRS "
    "(e.g., X, Latitude)\",\"type\":\"number\"},\"crs\":{\"description\":\"Global "
    "Coordinate Reference "
    "System\",\"properties\":{\"wkt\":{\"description\":\"\\\"Well-Known Text\\\" "
    "string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w"
    "kt-crs)\",\"type\":\"string\"},\"epsg\":{\"description\":\"EPSG code\",\"minimum\":"
    "0,\"type\":\"integer\"}},\"required\":[\"epsg\"],\"type\":\"object\"},\"coordinate_"
    "3\":{\"description\":\"Coordinate 3 as defined by axis 3 of the specified "
    "CRS (e.g., Z, Altitude)\",\"type\":\"number\"},\"vertical_accuracy\":{\"descri"
    "ption\":\"Vertical accuracy [m]\",\"minimum\":0,\"exclusiveMinimum\":true,\"ty"
    "pe\":\"number\"}},\"required\":[\"coordinate_1\",\"coordinate_2\",\"coordinate_3"
    "\",\"horizontal_accuracy\",\"vertical_accuracy\",\"crs\"],\"type\":\"object\"}},\""
    "title\":\"Pose Estimation\",\"$schema\":\"http://json-schema.org/draft-04/sc"
    "hema#\",\"type\":\"object\",\"required\":[\"orientation\"]}"
    ,
    /* example: */
    "{\"barometric_height_amsl\":386.7457796227932,\"orientation\":{\"yaw_accura"
    "cy\":1.0094337839368757,\"roll_accuracy\":0.009433783936875745,\"pitch\":1."
    "509153024827064,\"pitch_accuracy\":0.009433783936875745,\"roll\":3.1474307"
    "3066123,\"yaw\":101.87293630292045},\"position\":{\"coordinate_2\":15.645033"
    "406,\"horizontal_accuracy\":0.810699999332428,\"coordinate_1\":48.65579947"
    "3,\"crs\":{\"wkt\":\"GEOGCS[\\\"WGS84 / Geographic\\\",DATUM[\\\"WGS84\\\",SPHEROID"
    "[\\\"WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AUT"
    "HORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000000000000,AUT"
    "HORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Degree\\\",0.01745329251994329547,AUTH"
    "ORITY[\\\"EPSG\\\",\\\"9102\\\"]],AXIS[\\\"Latitude\\\",NORTH],AXIS[\\\"Longitude\\\","
    "EAST],AUTHORITY[\\\"EPSG\\\",\\\"4979\\\"]]\",\"epsg\":4979},\"coordinate_3\":362.7"
    "124938964844,\"vertical_accuracy\":1.3314999341964722}}"
};

// Details on position and orientation sensors
const MetaDataItemInfo RDB_RIEGL_POSE_SENSORS = {
    /* name        */ "riegl.pose_sensors",
    /* title       */ "Pose Sensors",
    /* description */ "Details on position and orientation sensors",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details on position and orientation sensors\",\"properti"
    "es\":{\"magnetic_field_sensor\":{\"description\":\"Magnetic Field Sensor "
    "details\",\"properties\":{\"y_axis\":{\"description\":\"Sensitive Y axis of "
    "sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"x_axis\":{\"description\":\"Sensitive X"
    " axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"unit\":{\"description\":\"Unit of raw "
    "data and calibration values, 1 LSB in nT\",\"minimum\":0,\"exclusiveMinimu"
    "m\":true,\"type\":\"number\"},\"z_axis\":{\"description\":\"Sensitive Z axis of "
    "sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"offset\":{\"description\":\"Value to be"
    " subtracted from raw measurement values\",\"$ref\":\"#/definitions/vector\""
    "},\"fixed\":{\"description\":\"Distortion of magnetic field caused by "
    "non-rotating scanner part\",\"$ref\":\"#/definitions/vector\"},\"relative_no"
    "nlinearity\":{\"description\":\"Relative nonlinearity, dimensionless\",\"$re"
    "f\":\"#/definitions/vector\"}},\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_ax"
    "is\",\"offset\",\"fixed\",\"relative_nonlinearity\"],\"type\":\"object\"},\"accele"
    "rometer\":{\"description\":\"Accelerometer "
    "details\",\"properties\":{\"y_axis\":{\"description\":\"Sensitive Y axis of "
    "sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"x_axis\":{\"description\":\"Sensitive X"
    " axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"unit\":{\"description\":\"Unit of raw "
    "data and calibration values, 1 LSB in 9.81 m/s\\u00b2\",\"minimum\":0,\"exc"
    "lusiveMinimum\":true,\"type\":\"number\"},\"z_axis\":{\"description\":\"Sensitiv"
    "e Z axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"offset\":{\"description\":\"Value to be"
    " subtracted from raw measurement "
    "values\",\"$ref\":\"#/definitions/vector\"},\"origin\":{\"description\":\"Sensor"
    " origin in SOCS [m] at frame angle = 0\",\"$ref\":\"#/definitions/vector\"}"
    ",\"relative_nonlinearity\":{\"description\":\"Relative nonlinearity, dimens"
    "ionless\",\"$ref\":\"#/definitions/vector\"}},\"required\":[\"unit\",\"x_axis\",\""
    "y_axis\",\"z_axis\",\"offset\",\"origin\",\"relative_nonlinearity\"],\"type\":\"ob"
    "ject\"},\"gyroscope\":{\"description\":\"Gyroscope "
    "details\",\"properties\":{\"y_axis\":{\"description\":\"Sensitive Y axis of "
    "sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"x_axis\":{\"description\":\"Sensitive X"
    " axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"unit\":{\"description\":\"Unit of raw "
    "data and calibration values, 1 LSB in rad/s\",\"minimum\":0,\"exclusiveMin"
    "imum\":true,\"type\":\"number\"},\"z_axis\":{\"description\":\"Sensitive Z axis "
    "of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"offset\":{\"description\":\"Value to be"
    " subtracted from raw measurement "
    "values\",\"$ref\":\"#/definitions/vector\"},\"origin\":{\"description\":\"Sensor"
    " origin in SOCS [m] at frame angle = 0\",\"$ref\":\"#/definitions/vector\"}"
    ",\"relative_nonlinearity\":{\"description\":\"Relative nonlinearity, dimens"
    "ionless\",\"$ref\":\"#/definitions/vector\"}},\"required\":[\"unit\",\"x_axis\",\""
    "y_axis\",\"z_axis\",\"offset\",\"origin\",\"relative_nonlinearity\"],\"type\":\"ob"
    "ject\"}},\"title\":\"Pose Sensors\",\"$schema\":\"http://json-schema.org/draft"
    "-04/schema#\",\"type\":\"object\",\"required\":[\"gyroscope\",\"accelerometer\",\""
    "magnetic_field_sensor\"],\"definitions\":{\"vector\":{\"items\":{\"description"
    "\":\"Index 0=X, 1=Y, 2=Z component\",\"type\":\"number\"},\"minItems\":3,\"maxIt"
    "ems\":3,\"type\":\"array\"}}}"
    ,
    /* example: */
    "{\"magnetic_field_sensor\":{\"y_axis\":[0.00027888521435670555,-0.01142742"
    "4848079681,-5.204829722060822e-05],\"x_axis\":[-0.011162743903696537,-2."
    "315962774446234e-05,0.00016818844596855342],\"unit\":91.74311828613281,\""
    "z_axis\":[0.00041987866279669106,7.876977906562388e-05,0.01140710432082"
    "4146],\"offset\":[-23812.052734375,5606.57666015625,2493.28125],\"fixed\":"
    "[-1576.010498046875,1596.081787109375,0.0],\"relative_nonlinearity\":[0."
    "0,0.0,0.0]},\"accelerometer\":{\"y_axis\":[-7.027288913726807,-44.12333679"
    "199219,14952.3701171875],\"x_axis\":[-15008.123046875,56.956390380859375"
    ",-60.5175666809082],\"unit\":6.666666740784422e-05,\"z_axis\":[1.639882206"
    "916809,15166.744140625,-116.99742889404297],\"offset\":[-733.36364746093"
    "75,58.969032287597656,1060.2550048828125],\"origin\":[0.0269000008702278"
    "14,-0.03999999910593033,-0.08950000256299973],\"relative_nonlinearity\":"
    "[0.0,0.0,0.0]},\"gyroscope\":{\"y_axis\":[-0.440765917301178,-0.7897399663"
    "925171,119.5894775390625],\"x_axis\":[-121.195556640625,0.82197141647338"
    "87,0.2313031703233719],\"unit\":0.00014544410805683583,\"z_axis\":[0.55586"
    "9996547699,119.22135162353516,0.467585027217865],\"offset\":[-50.9260978"
    "6987305,146.15643310546875,62.4327278137207],\"origin\":[0.0269000008702"
    "27814,-0.03999999910593033,-0.08950000256299973],\"relative_nonlinearit"
    "y\":[2.888176311444113e-07,1.06274164579645e-07,-1.7186295080634935e-39"
    "]}}"
};

// Laser pulse position modulation used for MTA resolution
const MetaDataItemInfo RDB_RIEGL_PULSE_POSITION_MODULATION = {
    /* name        */ "riegl.pulse_position_modulation",
    /* title       */ "Pulse Position Modulation",
    /* description */ "Laser pulse position modulation used for MTA resolution",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Laser pulse position modulation used for MTA "
    "resolution\",\"properties\":{\"code_phase_mode\":{\"description\":\"0: no "
    "synchronization, 1: toggle between 2 phases, 2: increment with phase_i"
    "ncrement\",\"minimum\":0,\"maximum\":255,\"type\":\"integer\"},\"num_mod_ampl\":{"
    "\"description\":\"Number of different modulation amplitudes (2: binary mo"
    "dulation)\",\"minimum\":0,\"maximum\":255,\"type\":\"integer\"},\"pulse_interval"
    "\":{\"description\":\"Explicit table of the pulse position modulation used"
    " for MTA resolution. Table gives times between successive laser pulses"
    " in seconds.\",\"items\":{\"minimum\":0,\"type\":\"number\"},\"type\":\"array\"},\"p"
    "hase_step\":{\"description\":\"Step width in phase of modulation code from"
    " line to line\",\"minimum\":0,\"maximum\":255,\"type\":\"integer\"},\"length\":{\""
    "description\":\"Length of "
    "code\",\"minimum\":0,\"maximum\":255,\"type\":\"integer\"}},\"title\":\"Pulse "
    "Position Modulation\",\"$schema\":\"http://json-schema.org/draft-04/schema"
    "#\",\"type\":\"object\",\"required\":[\"length\",\"num_mod_ampl\",\"pulse_interval"
    "\"]}"
    ,
    /* example: */
    "{\"code_phase_mode\":2,\"num_mod_ampl\":2,\"pulse_interval\":[2.759375e-06,2"
    ".759375e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.7593"
    "75e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.759375e-0"
    "6,2.759375e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.8"
    "21875e-06,2.759375e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875"
    "e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,"
    "2.821875e-06,2.759375e-06,2.821875e-06],\"phase_step\":5,\"length\":31}"
};

// Statistics about target distance wrt. SOCS origin
const MetaDataItemInfo RDB_RIEGL_RANGE_STATISTICS = {
    /* name        */ "riegl.range_statistics",
    /* title       */ "Range Statistics",
    /* description */ "Statistics about target distance wrt. SOCS origin",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Statistics about target distance wrt. SOCS "
    "origin\",\"properties\":{\"std_dev\":{\"description\":\"Standard "
    "deviation\",\"type\":\"number\"},\"maximum\":{\"description\":\"Maximum "
    "value\",\"type\":\"number\"},\"average\":{\"description\":\"Average "
    "value\",\"type\":\"number\"},\"minimum\":{\"description\":\"Minimum "
    "value\",\"type\":\"number\"}},\"title\":\"Range Statistics\",\"$schema\":\"http://"
    "json-schema.org/draft-04/schema#\",\"type\":\"object\",\"required\":[\"minimum"
    "\",\"average\",\"maximum\",\"std_dev\"]}"
    ,
    /* example: */
    "{\"std_dev\":24.349,\"maximum\":574.35,\"average\":15.49738,\"minimum\":0.919}"
};

// Receiver Internals
const MetaDataItemInfo RDB_RIEGL_RECEIVER_INTERNALS = {
    /* name        */ "riegl.receiver_internals",
    /* title       */ "Receiver Internals",
    /* description */ "Receiver Internals",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Receiver "
    "Internals\",\"properties\":{\"nt\":{\"description\":\"Number of traces\",\"minim"
    "um\":0,\"maximum\":255,\"type\":\"integer\"},\"a\":{\"description\":\"Amplitude [d"
    "B]\",\"items\":{\"type\":\"number\"},\"minItems\":1,\"maxItems\":256,\"type\":\"arra"
    "y\"},\"si\":{\"description\":\"Start index (hw_start)\",\"minimum\":0,\"maximum\""
    ":255,\"type\":\"number\"},\"sr\":{\"description\":\"Sample rate [Hz]\",\"minimum\""
    ":0,\"exclusiveMinimum\":true,\"type\":\"number\"},\"mw\":{\"description\":\"Maxim"
    "um weight\",\"minimum\":0,\"exclusiveMinimum\":true,\"maximum\":4095,\"type\":\""
    "number\"},\"ns\":{\"description\":\"Number of samples\",\"minimum\":0,\"maximum\""
    ":4095,\"type\":\"integer\"},\"t\":{\"additionalProperties\":false,\"patternProp"
    "erties\":{\"^[0-9]+$\":{\"description\":\"one field per channel, field name "
    "is channel index\",\"$ref\":\"#/definitions/fp\"}},\"type\":\"object\"},\"tbl\":{"
    "\"description\":\"various internal data\",\"items\":{\"$ref\":\"#/definitions/f"
    "p_table\"},\"minItems\":1,\"type\":\"array\"},\"ex\":{\"description\":\"DEPRECATED"
    ", use 'riegl.exponential_decomposition' "
    "instead\",\"type\":\"object\"}},\"title\":\"Receiver Internals\",\"$schema\":\"htt"
    "p://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"definitions\":{\""
    "fp_table\":{\"required\":[\"ch\",\"tc\",\"nx\",\"ny\",\"tv\"],\"properties\":{\"nx\":{\""
    "max\":2048,\"min\":1,\"description\":\"number of x entries\",\"type\":\"integer\""
    "},\"ch\":{\"max\":255,\"min\":0,\"description\":\"channel "
    "number\",\"type\":\"integer\"},\"tc\":{\"max\":255,\"min\":0,\"description\":\"table"
    " data type code\",\"type\":\"integer\"},\"tv\":{\"minItems\":1,\"items\":{\"oneOf\""
    ":[{\"$ref\":\"#/definitions/fp_table_row\"},{\"type\":\"number\"}]},\"maxItems\""
    ":2048,\"type\":\"array\"},\"ny\":{\"max\":2048,\"min\":1,\"description\":\"number "
    "of y entries\",\"type\":\"integer\"}},\"desription\":\"scanner internal data\","
    "\"type\":\"object\"},\"fp_table_row\":{\"minItems\":1,\"items\":{\"type\":\"number\""
    "},\"maxItems\":2048,\"type\":\"array\"},\"fp\":{\"description\":\"Fingerprint val"
    "ues\",\"properties\":{\"s\":{\"items\":{\"items\":{\"type\":\"number\"},\"minItems\":"
    "1,\"maxItems\":4096,\"type\":\"array\"},\"minItems\":1,\"maxItems\":256,\"type\":\""
    "array\"},\"w\":{\"items\":{\"items\":{\"type\":\"number\"},\"minItems\":5,\"maxItems"
    "\":5,\"type\":\"array\"},\"minItems\":1,\"maxItems\":256,\"type\":\"array\"}},\"requ"
    "ired\":[\"s\",\"w\"],\"type\":\"object\"}}}"
    ,
    /* example: */
    "{\"nt\":128,\"a\":[-1.55],\"si\":48,\"sr\":7959997000.0,\"mw\":31,\"ns\":400,\"t\":{"
    "\"1\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,134,31],[78,86,126,"
    "134,31]]},\"0\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,134,31],["
    "78,86,126,134,31]]}},\"tbl\":[{\"nx\":5,\"ch\":0,\"tc\":1,\"tv\":[[1,2,3,4,5],[1"
    ".1,2.2,3.3,4.4,5.5]],\"ny\":2}]}"
};

// Lookup table for reflectance calculation based on amplitude and range
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CALCULATION = {
    /* name        */ "riegl.reflectance_calculation",
    /* title       */ "Reflectance Calculation Table",
    /* description */ "Lookup table for reflectance calculation based on amplitude and range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Lookup table for reflectance calculation based on "
    "amplitude and range\",\"properties\":{\"delta\":{\"description\":\"Delta "
    "between table entries [m], first entry is at range = 0 "
    "m\",\"type\":\"number\"},\"content\":{\"description\":\"Correction value [dB] to"
    " be added to the amplitude\",\"items\":{\"type\":\"number\"},\"minItems\":1,\"ma"
    "xItems\":2000,\"type\":\"array\"}},\"title\":\"Reflectance Calculation Table\","
    "\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"r"
    "equired\":[\"delta\",\"content\"]}"
    ,
    /* example: */
    "{\"delta\":0.150918,\"content\":[-33.01]}"
};

// Range-dependent and scan-angle-dependent correction of reflectance reading
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CORRECTION = {
    /* name        */ "riegl.reflectance_correction",
    /* title       */ "Near-Range Reflectance Correction",
    /* description */ "Range-dependent and scan-angle-dependent correction of reflectance reading",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Range-dependent and scan-angle-dependent correction of"
    " reflectance reading\",\"properties\":{\"ranges_m\":{\"description\":\"Range ["
    "m]\",\"items\":{\"type\":\"number\"},\"type\":\"array\"},\"line_angles_deg\":{\"desc"
    "ription\":\"Angle [deg]\",\"items\":{\"type\":\"number\"},\"type\":\"array\"},\"refl"
    "ectance_correction_db\":{\"description\":\"Near range reflectance "
    "correction in dB as a function of range over "
    "angle\",\"items\":{\"description\":\"rows (each array corresponds to a "
    "range)\",\"items\":{\"description\":\"columns (each value corresponds to an "
    "angle)\",\"type\":\"number\"},\"type\":\"array\"},\"type\":\"array\"}},\"title\":\"Nea"
    "r-range reflectance correction\",\"$schema\":\"http://json-schema.org/draf"
    "t-04/schema#\",\"type\":\"object\",\"required\":[\"ranges_m\",\"line_angles_deg\""
    ",\"reflectance_correction_db\"]}"
    ,
    /* example: */
    "{\"ranges_m\":[0.0,1.0,2.0,3.0],\"line_angles_deg\":[0.0,0.5,1.0,1.5,1.0,2"
    ".0,2.5,3.0,3.5,4.0],\"reflectance_correction_db\":[[0.8,0.7,0.6,0.5,0.4,"
    "0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0."
    "8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,"
    "0.1,0.05,0.01]]}"
};

// Scan pattern description
const MetaDataItemInfo RDB_RIEGL_SCAN_PATTERN = {
    /* name        */ "riegl.scan_pattern",
    /* title       */ "Scan Pattern",
    /* description */ "Scan pattern description",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Scan pattern "
    "description\",\"properties\":{\"segments\":{\"description\":\"Segmented Line "
    "Scan Pattern\",\"properties\":{\"program\":{\"$ref\":\"#/definitions/program\"}"
    ",\"list\":{\"items\":{\"description\":\"Line Scan "
    "Segment\",\"properties\":{\"start\":{\"description\":\"Start angle in SOCS [de"
    "g]\",\"minimum\":0.0,\"maximum\":360.0,\"type\":\"number\"},\"increment\":{\"descr"
    "iption\":\"Increment of angle in SOCS [deg]\",\"minimum\":0.0,\"maximum\":90."
    "0,\"type\":\"number\"},\"stop\":{\"description\":\"Stop angle in SOCS [deg]\",\"m"
    "inimum\":0.0,\"maximum\":720.0,\"type\":\"number\"}},\"required\":[\"start\",\"sto"
    "p\",\"increment\"],\"type\":\"object\"},\"type\":\"array\"}},\"required\":[\"list\"],"
    "\"type\":\"object\"},\"rectangular\":{\"description\":\"Rectangular Field Of "
    "View Scan Pattern\",\"properties\":{\"theta_stop\":{\"description\":\"Stop "
    "theta angle in SOCS [deg]\",\"minimum\":0.0,\"maximum\":180.0,\"type\":\"numbe"
    "r\"},\"phi_increment\":{\"description\":\"Increment of phi angle in SOCS [de"
    "g]\",\"minimum\":0.0,\"maximum\":90.0,\"type\":\"number\"},\"program\":{\"$ref\":\"#"
    "/definitions/program\"},\"theta_start\":{\"description\":\"Start theta angle"
    " in SOCS [deg]\",\"minimum\":0.0,\"maximum\":180.0,\"type\":\"number\"},\"phi_st"
    "art\":{\"description\":\"Start phi angle in SOCS [deg]\",\"minimum\":0.0,\"max"
    "imum\":360.0,\"type\":\"number\"},\"theta_increment\":{\"description\":\"Increme"
    "nt of theta angle in SOCS [deg]\",\"minimum\":0.0,\"maximum\":90.0,\"type\":\""
    "number\"},\"phi_stop\":{\"description\":\"Stop phi angle in SOCS [deg]\",\"min"
    "imum\":0.0,\"maximum\":720.0,\"type\":\"number\"}},\"required\":[\"phi_start\",\"p"
    "hi_stop\",\"phi_increment\",\"theta_start\",\"theta_stop\",\"theta_increment\"]"
    ",\"type\":\"object\"},\"line\":{\"description\":\"Line Scan Pattern\",\"propertie"
    "s\":{\"program\":{\"$ref\":\"#/definitions/program\"},\"start\":{\"description\":"
    "\"Start angle in SOCS [deg]\",\"minimum\":0.0,\"maximum\":360.0,\"type\":\"numb"
    "er\"},\"increment\":{\"description\":\"Increment of angle in SOCS [deg]\",\"mi"
    "nimum\":0.0,\"maximum\":90.0,\"type\":\"number\"},\"stop\":{\"description\":\"Stop"
    " angle in SOCS [deg]\",\"minimum\":0.0,\"maximum\":720.0,\"type\":\"number\"}},"
    "\"required\":[\"start\",\"stop\",\"increment\"],\"type\":\"object\"}},\"title\":\"Sca"
    "n Pattern\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"defini"
    "tions\":{\"program\":{\"description\":\"Measurement "
    "program\",\"properties\":{\"laser_prr\":{\"description\":\"Laser Pulse "
    "Repetition Rate [Hz]\",\"minimum\":0,\"exclusiveMinimum\":false,\"type\":\"num"
    "ber\"},\"name\":{\"description\":\"Name of measurement "
    "program\",\"type\":\"string\"}},\"required\":[\"name\"],\"type\":\"object\"}}}"
    ,
    /* example: */
    "{\"rectangular\":{\"theta_stop\":130.0,\"phi_increment\":0.04,\"program\":{\"la"
    "ser_prr\":100000.0,\"name\":\"High Speed\"},\"theta_start\":30.0,\"phi_start\":"
    "45.0,\"theta_increment\":0.04,\"phi_stop\":270.0}}"
};

// Details about laser shot files
const MetaDataItemInfo RDB_RIEGL_SHOT_INFO = {
    /* name        */ "riegl.shot_info",
    /* title       */ "Shot Information",
    /* description */ "Details about laser shot files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about laser shot files\",\"properties\":{\"shot_fi"
    "le\":{\"properties\":{\"file_uuid\":{\"description\":\"File's Universally "
    "Unique Identifier (RFC "
    "4122)\",\"type\":\"string\"},\"file_extension\":{\"description\":\"Shot file "
    "extension, without the leading dot\",\"type\":\"string\"}},\"required\":[\"fil"
    "e_extension\"],\"type\":\"object\"}},\"title\":\"Shot Information\",\"$schema\":\""
    "http://json-schema.org/draft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"shot_file\":{\"file_uuid\":\"26a00815-67c0-4bff-8fe8-c577378fe663\",\"file"
    "_extension\":\"sodx\"}}"
};

// Point filters applied in addition to the application-defined filters
const MetaDataItemInfo RDB_RIEGL_STORED_FILTERS = {
    /* name        */ "riegl.stored_filters",
    /* title       */ "Stored Filters",
    /* description */ "Point filters applied in addition to the application-defined filters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Point filters applied in addition to the "
    "application-defined "
    "filters\",\"properties\":{\"activated\":{\"description\":\"Apply ('true') or "
    "ignore ('false') all "
    "filters\",\"type\":\"boolean\"},\"filters\":{\"description\":\"List of point "
    "filters\",\"items\":{\"description\":\"Point filter "
    "definition\",\"properties\":{\"description\":{\"description\":\"A brief "
    "description of the filter (e.g. for display in a "
    "tooltip)\",\"type\":\"string\"},\"activated\":{\"description\":\"Apply ('true') "
    "or ignore ('false') this "
    "filter\",\"type\":\"boolean\"},\"title\":{\"description\":\"A short filter title"
    " (e.g. for display in a selection "
    "list)\",\"type\":\"string\"},\"filter\":{\"description\":\"The RDB filter string"
    " to apply (e.g. when reading points or index), details see "
    "documentation of function select()\",\"type\":\"string\"}},\"required\":[\"act"
    "ivated\",\"title\",\"description\",\"filter\"],\"type\":\"object\"},\"type\":\"array"
    "\"}},\"title\":\"Stored filters\",\"$schema\":\"http://json-schema.org/draft-0"
    "4/schema#\",\"type\":\"object\",\"required\":[\"activated\",\"filters\"]}"
    ,
    /* example: */
    "{\"activated\":true,\"filters\":[{\"description\":\"Ignore points with "
    "uncertain MTA zone assignment\",\"activated\":false,\"title\":\"Ignore "
    "uncertain points from MTA "
    "resolution\",\"filter\":\"riegl.mta_uncertain_point == "
    "0\"},{\"description\":\"Ignore points with an echo signal amplitude below "
    "the dynamic trigger\",\"activated\":false,\"title\":\"Ignore points below "
    "dynamic trigger level\",\"filter\":\"riegl.dyntrig_uncertain_point == "
    "0\"},{\"description\":\"Ignore points that are outside the outer AABB in "
    "BOCS\",\"activated\":false,\"title\":\"Ignore points outside outer "
    "AABB\",\"filter\":\"riegl.point_outside_aabb_bocs == "
    "0\"},{\"description\":\"Ignore points that are inside the inner AABB in "
    "BOCS\",\"activated\":false,\"title\":\"Ignore points inside inner "
    "AABB\",\"filter\":\"riegl.point_inside_aabb_bocs == 0\"}]}"
};

// Details of major system components like lidar sensors, cameras and navigation devices
const MetaDataItemInfo RDB_RIEGL_SYSTEM_DESCRIPTION = {
    /* name        */ "riegl.system_description",
    /* title       */ "System Description",
    /* description */ "Details of major system components like lidar sensors, cameras and navigation devices",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details of major system components like lidar sensors,"
    " cameras and navigation "
    "devices\",\"properties\":{\"version\":{\"description\":\"Document format "
    "version\",\"type\":\"string\"},\"$class\":{\"description\":\"Object class name\","
    "\"enum\":[\"Document\"],\"type\":\"string\"},\"author\":{\"description\":\"Name of "
    "the author that created the "
    "document\",\"type\":\"string\"},\"timestamp\":{\"description\":\"Date and time "
    "of creation (e.g. 2019-06-19T13:32:10+02:00)\",\"type\":\"string\"},\"system"
    "\":{\"description\":\"The actual system description, details see "
    "documentation of RIEGL System "
    "Description\",\"type\":\"object\"}},\"title\":\"System Description\",\"$schema\":"
    "\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"required\":["
    "\"$class\",\"version\",\"author\",\"timestamp\",\"system\"]}"
    ,
    /* example: */
    "{\"version\":\"1.2.1\",\"$class\":\"Document\",\"author\":\"RIEGL LMS GmbH, Austr"
    "ia\",\"timestamp\":\"2022-09-30T11:56:26+00:00\",\"system\":{\"details\":\"see "
    "documentation of RIEGL System Description\"}}"
};

// Conversion of background radiation raw values to temperatures in °C
const MetaDataItemInfo RDB_RIEGL_TEMPERATURE_CALCULATION = {
    /* name        */ "riegl.temperature_calculation",
    /* title       */ "Temperature Calculation Table",
    /* description */ "Conversion of background radiation raw values to temperatures in °C",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Conversion of background radiation raw values to "
    "temperatures in \\u00b0C\",\"properties\":{\"Si\":{\"description\":\"Conversion"
    " table for Si channel\",\"$ref\":\"#/definitions/conversion_table\"},\"InGaA"
    "s\":{\"description\":\"Conversion table for InGaAs channel\",\"$ref\":\"#/defi"
    "nitions/conversion_table\"},\"InGaAs_Si_Difference\":{\"description\":\"Conv"
    "ersion table for InGaAs - Si difference\",\"$ref\":\"#/definitions/convers"
    "ion_table\"}},\"title\":\"Temperature Calculation Table\",\"$schema\":\"http:/"
    "/json-schema.org/draft-04/schema#\",\"type\":\"object\",\"definitions\":{\"con"
    "version_table\":{\"properties\":{\"temperature\":{\"description\":\"Temperatur"
    "e [\\u00b0C]\",\"items\":{\"type\":\"number\"},\"type\":\"array\"},\"value\":{\"descr"
    "iption\":\"LSB [1]\",\"items\":{\"type\":\"number\"},\"type\":\"array\"}},\"required"
    "\":[\"value\",\"temperature\"],\"type\":\"object\"}}}"
    ,
    /* example: */
    "{\"Si\":{\"temperature\":[546.300048828125,548.8164051212026,551.314393850"
    "0972,554.0144257850053,556.604252334815,559.2124464488079,561.80227299"
    "86177,564.4104671126105,567.0002936624203],\"value\":[0.0,64.00097659230"
    "323,128.0019531846065,192.0029297769097,256.0039063692129,320.00488296"
    "151616,384.0058595538194,448.0068361461226,512.0078127384259]},\"InGaAs"
    "\":{\"temperature\":[307.22196722535614,309.1153478247277,311.11880869150"
    "47,313.10025350480055,315.2137946389828,317.2172555057597,319.22071637"
    "25366,321.2021611858325,323.3157023200148],\"value\":[0.0,64.00097659230"
    "323,128.0019531846065,192.0029297769097,256.0039063692129,320.00488296"
    "151616,384.0058595538194,448.0068361461226,512.0078127384259]},\"InGaAs"
    "_Si_Difference\":{\"temperature\":[1749.977111117893,1749.977111117893,17"
    "49.977111117893,1749.977111117893,1749.977111117893,1749.977111117893,"
    "1744.7813348796044,1681.9971312601092,1622.3944822534868],\"value\":[100"
    "0.0,1100.090029602954,1200.04425183874,1300.1342814416948,1400.0885036"
    "774805,1500.0427259132668,1600.1327555162209,1700.0869777520065,1800.0"
    "411999877924]}}"
};

// Base of timestamps (epoch)
const MetaDataItemInfo RDB_RIEGL_TIME_BASE = {
    /* name        */ "riegl.time_base",
    /* title       */ "Time Base",
    /* description */ "Base of timestamps (epoch)",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Base of timestamps "
    "(epoch)\",\"properties\":{\"epoch\":{\"description\":\"Date and time of "
    "timestamp '0' as proposed by RFC 3339 (e.g. 2015-10-27T00:00:00+01:00)"
    ".\",\"type\":\"string\"},\"source\":{\"description\":\"Timestamp source\",\"enum\":"
    "[\"unknown\",\"RTC\",\"GNSS\"],\"type\":\"string\"},\"system\":{\"description\":\"Tim"
    "e system (time standard)\",\"enum\":[\"unknown\",\"UTC\",\"GPS\"],\"type\":\"strin"
    "g\"}},\"title\":\"Time Base\",\"$schema\":\"http://json-schema.org/draft-04/sc"
    "hema#\",\"type\":\"object\",\"required\":[\"epoch\",\"source\"]}"
    ,
    /* example: */
    "{\"epoch\":\"2015-10-27T00:00:00+00:00\",\"source\":\"GNSS\",\"system\":\"UTC\"}"
};

// Details about position+orientation files
const MetaDataItemInfo RDB_RIEGL_TRAJECTORY_INFO = {
    /* name        */ "riegl.trajectory_info",
    /* title       */ "Trajectory Information",
    /* description */ "Details about position+orientation files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about position+orientation "
    "files\",\"properties\":{\"project\":{\"description\":\"Project "
    "name\",\"type\":\"string\"},\"company\":{\"description\":\"Company "
    "name\",\"type\":\"string\"},\"field_of_application\":{\"description\":\"Field of"
    " application\",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\",\"B"
    "LS\",\"ILS\"],\"type\":\"string\"},\"navigation_frame\":{\"description\":\"Navigat"
    "ion frame (NED: North-East-Down, ENU: East-North-Up)\",\"enum\":[\"unknown"
    "\",\"NED\",\"ENU\"],\"type\":\"string\"},\"software\":{\"description\":\"Software "
    "that calculated the trajectory (this may be the same or different "
    "software than the one that created the "
    "file)\",\"type\":\"string\"},\"time_interval\":{\"description\":\"Time interval "
    "statistics\",\"properties\":{\"std_dev\":{\"description\":\"Standard deviation"
    " of intervals [s]\",\"type\":\"number\"},\"maximum\":{\"description\":\"Maximum "
    "time interval [s]\",\"type\":\"number\"},\"average\":{\"description\":\"Average "
    "time interval [s]\",\"type\":\"number\"},\"minimum\":{\"description\":\"Minimum "
    "time interval [s]\",\"type\":\"number\"}},\"required\":[\"minimum\",\"average\",\""
    "maximum\",\"std_dev\"],\"type\":\"object\"},\"settings\":{\"description\":\"Settin"
    "gs used to calculate the trajectory (descriptive "
    "text)\",\"type\":\"string\"},\"location\":{\"description\":\"Project location, "
    "e.g. city/state/country\",\"type\":\"string\"},\"device\":{\"description\":\"Nav"
    "igation device, e.g. "
    "name/type/serial\",\"type\":\"string\"}},\"title\":\"Trajectory Information\",\""
    "$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"re"
    "quired\":[\"time_interval\",\"navigation_frame\"]}"
    ,
    /* example: */
    "{\"project\":\"Campaign 3\",\"company\":\"RIEGL LMS\",\"field_of_application\":\""
    "MLS\",\"navigation_frame\":\"NED\",\"software\":\"Navigation Software XYZ\",\"ti"
    "me_interval\":{\"std_dev\":5.51e-07,\"maximum\":0.005004883,\"average\":0.005"
    "00053,\"minimum\":0.00500032},\"settings\":\"default\",\"location\":\"Horn\",\"de"
    "vice\":\"IMU Model 12/1, Serial# 12345\"}"
};

// Trigger-Timestamping-Unit/IP configuration
const MetaDataItemInfo RDB_RIEGL_TTIP_CONFIGURATION = {
    /* name        */ "riegl.ttip_configuration",
    /* title       */ "TTIP Configuration",
    /* description */ "Trigger-Timestamping-Unit/IP configuration",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Trigger-Timestamping-Unit/IP "
    "configuration\",\"properties\":{\"input_usage\":{\"description\":\"0 .. "
    "deactivated, 1 .. just detecting and timestamping\",\"minimum\":0,\"type\":"
    "\"integer\"},\"out_interval\":{\"description\":\"output pulse interval [0.1 m"
    "sec]\",\"minimum\":0,\"type\":\"integer\"},\"out_duration\":{\"description\":\"out"
    "put pulse duration [0.1 msec]\",\"minimum\":0,\"type\":\"integer\"},\"dmi_max_"
    "time\":{\"description\":\"dmi, maximum time interval between trigger "
    "events [0.1 msec]\",\"minimum\":0,\"type\":\"integer\"},\"num_channel\":{\"descr"
    "iption\":\"number of input/output channels\",\"minimum\":0,\"type\":\"integer\""
    "},\"dmi_dist_per_tick\":{\"description\":\"dmi, distance per tick, just "
    "informative [m]\",\"type\":\"number\"},\"dmi_min_time\":{\"description\":\"dmi, "
    "minimum time interval between trigger events [0.1 msec]\",\"minimum\":0,\""
    "type\":\"integer\"},\"out_delay\":{\"description\":\"output pulse initial "
    "delay after start [0.1 msec]\",\"minimum\":0,\"type\":\"integer\"},\"out_num_p"
    "ulses\":{\"description\":\"number of output pulses to be generated, 0 .. i"
    "nfinite\",\"minimum\":0,\"type\":\"integer\"},\"input_descr\":{\"description\":\"d"
    "escriptive "
    "string\",\"type\":\"string\"},\"output_descr\":{\"description\":\"descriptive "
    "string\",\"type\":\"string\"},\"ext_bitmask\":{\"description\":\"defines which "
    "of the internal pulse generators are to be started\",\"minimum\":0,\"type\""
    ":\"integer\"},\"in_max_delay\":{\"description\":\"maximum delay to output "
    "pulse before fake event is generated [0.1 msec], zero indicates that "
    "no fake events are generated\",\"minimum\":0,\"type\":\"integer\"},\"in_polari"
    "ty\":{\"description\":\"0 .. positive edge, 1 .. negative edge\",\"minimum\":"
    "0,\"type\":\"integer\"},\"ext_delay\":{\"description\":\"external trigger, time"
    " delay [0.1 "
    "msec]\",\"minimum\":0,\"type\":\"integer\"},\"ext_signal\":{\"description\":\"0 .."
    " use input signal, 1 .. use output signal of "
    "channel\",\"minimum\":0,\"type\":\"integer\"},\"dmi_incr\":{\"description\":\"dmi,"
    " increment in "
    "ticks\",\"type\":\"integer\"},\"in_min_duration\":{\"description\":\"input "
    "signals with smaller pulse durations are ignored [0.1 msec]\",\"minimum\""
    ":0,\"type\":\"integer\"},\"in_max_duration\":{\"description\":\"stops "
    "measurement of pulse duration of input signal [0.1 "
    "msec]\",\"minimum\":0,\"type\":\"integer\"},\"channel\":{\"description\":\"ID of "
    "input/output channel\",\"minimum\":0,\"type\":\"integer\"},\"ext_subdivider\":{"
    "\"description\":\"reduces the frequency, default "
    "1\",\"minimum\":0,\"type\":\"integer\"},\"out_polarity\":{\"description\":\"0 .. "
    "positive edge, 1 .. negative "
    "edge\",\"minimum\":0,\"type\":\"integer\"},\"ext_channel\":{\"description\":\"ID "
    "of channel used as external trigger input, 32 indicates "
    "none\",\"minimum\":0,\"type\":\"integer\"},\"output_usage\":{\"description\":\"0 "
    ".. no output, 1 .. output derived from internal clock, 2 .. output "
    "derived from dmi, 3 .. output derived from external signal, 4 .. "
    "output static low, 5 .. output static high\",\"minimum\":0,\"type\":\"intege"
    "r\"},\"ttip_version\":{\"description\":\"following "
    "main.sub.ss.sss\",\"minimum\":0,\"type\":\"integer\"}},\"title\":\"TTIP Configur"
    "ation\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"obj"
    "ect\",\"required\":[\"ttip_version\",\"num_channel\",\"ext_channel\",\"ext_signa"
    "l\",\"ext_delay\",\"ext_subdivider\",\"ext_bitmask\",\"dmi_incr\",\"dmi_min_time"
    "\",\"dmi_max_time\",\"dmi_dist_per_tick\",\"channel\",\"output_descr\",\"input_d"
    "escr\",\"output_usage\",\"input_usage\",\"out_polarity\",\"out_duration\",\"out_"
    "interval\",\"out_delay\",\"out_num_pulses\",\"in_polarity\",\"in_min_duration\""
    ",\"in_max_duration\",\"in_max_delay\"]}"
    ,
    /* example: */
    "{\"input_usage\":1,\"out_interval\":10000,\"out_duration\":300,\"dmi_max_time"
    "\":0,\"num_channel\":9,\"dmi_dist_per_tick\":0.0,\"dmi_min_time\":0,\"out_dela"
    "y\":0,\"out_num_pulses\":1,\"input_descr\":\"Port 1 - "
    "Exposure\",\"output_descr\":\"Port 1 - Trigger\",\"ext_bitmask\":0,\"in_max_de"
    "lay\":9990,\"in_polarity\":0,\"ext_delay\":0,\"ext_signal\":0,\"dmi_incr\":0,\"i"
    "n_min_duration\":0,\"in_max_duration\":10000,\"channel\":0,\"ext_subdivider\""
    ":1,\"out_polarity\":0,\"ext_channel\":32,\"output_usage\":1,\"ttip_version\":1"
    "}"
};

// Details about vertex file
const MetaDataItemInfo RDB_RIEGL_VERTEX_INFO = {
    /* name        */ "riegl.vertex_info",
    /* title       */ "Vertex Information",
    /* description */ "Details about vertex file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about vertex file\",\"properties\":{\"vertex_file\""
    ":{\"properties\":{\"file_uuid\":{\"description\":\"File's Universally Unique "
    "Identifier (RFC "
    "4122)\",\"type\":\"string\"},\"file_extension\":{\"description\":\"Vertex file "
    "extension, without the leading dot\",\"type\":\"string\"}},\"required\":[\"fil"
    "e_extension\"],\"type\":\"object\"}},\"title\":\"Vertex Information\",\"$schema\""
    ":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"vertex_file\":{\"file_uuid\":\"51534d95-d71f-4f36-ae1a-3e63a21fd1c7\",\"fi"
    "le_extension\":\"vtx\"}}"
};

// Details about the voxels contained in the file
const MetaDataItemInfo RDB_RIEGL_VOXEL_INFO = {
    /* name        */ "riegl.voxel_info",
    /* title       */ "Voxel Information",
    /* description */ "Details about the voxels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about the voxels contained in the file\",\"oneOf"
    "\":[{\"additionalProperties\":false,\"properties\":{\"shape_thresholds\":{\"$r"
    "ef\":\"#/definitions/shape_thresholds\"},\"voxel_type\":{\"$ref\":\"#/definiti"
    "ons/voxel_type\"},\"size\":{\"description\":\"Size of voxels in file "
    "coordinate system.\",\"oneOf\":[{\"$ref\":\"#/definitions/voxel_size\"},{\"$re"
    "f\":\"#/definitions/voxel_size_cubic\"}]},\"voxel_origin\":{\"$ref\":\"#/defin"
    "itions/voxel_origin_enum\"}},\"required\":[\"size\",\"voxel_origin\",\"voxel_t"
    "ype\"]},{\"additionalProperties\":false,\"properties\":{\"shape_thresholds\":"
    "{\"$ref\":\"#/definitions/shape_thresholds\"},\"reference_point\":{\"descript"
    "ion\":\"Point in WGS84 geodetic decimal degree (EPSG:4326) that was used"
    " to compute the projection distortion parameters. The coefficient "
    "order is latitude, longitude. Only voxels with corresponding geo_tag, "
    "voxel_size and reference_point can be reliably processed together. "
    "This entry is available for voxel files in projected CRS only.\",\"type\""
    ":\"array\",\"minItems\":2,\"maxItems\":2,\"items\":{\"minimum\":-180,\"maximum\":1"
    "80,\"type\":\"number\"}},\"size_llcs\":{\"description\":\"Size of voxels in a "
    "locally levelled cartesian coordinate system (xyz). This is only used "
    "for voxels based on a map projection.\",\"$ref\":\"#/definitions/voxel_siz"
    "e\"},\"voxel_type\":{\"$ref\":\"#/definitions/voxel_type\"},\"size\":{\"descript"
    "ion\":\"Size of voxels in file coordinate system.\",\"$ref\":\"#/definitions"
    "/voxel_size\"},\"voxel_origin\":{\"oneOf\":[{\"$ref\":\"#/definitions/voxel_or"
    "igin_enum\"},{\"description\":\"The base point of the voxel grid. Used "
    "together with <tt>voxel_size</tt> and <tt>voxel_index</tt> to compute "
    "actual point coordinates.\",\"$ref\":\"#/definitions/voxel_origin_point\"}]"
    "}},\"required\":[\"reference_point\",\"size_llcs\",\"size\",\"voxel_origin\",\"vo"
    "xel_type\"]}],\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type"
    "\":\"object\",\"title\":\"Voxel Information\",\"definitions\":{\"shape_threshold"
    "s\":{\"description\":\"Thresholds used to compute the voxel's shape_id "
    "value.\",\"properties\":{\"plane\":{\"description\":\"If the smallest "
    "eigenvalue is smaller than the median eigenvalue * plane_threshold, "
    "the voxel is considered a plane.\",\"exclusiveMaximum\":true,\"type\":\"numb"
    "er\",\"exclusiveMinimum\":true,\"maximum\":1,\"minimum\":0},\"line\":{\"descript"
    "ion\":\"If the biggest eigenvalue is bigger than the median eigenvalue *"
    " line_threshold, the voxel is considered a line.\",\"minimum\":1,\"exclusi"
    "veMinimum\":true,\"type\":\"number\"}},\"required\":[\"plane\",\"line\"],\"type\":\""
    "object\"},\"voxel_origin_enum\":{\"description\":\"Defines whether the "
    "voxel's center or a corner is placed on CRS origin <tt>(0/0/0)</tt>.\","
    "\"enum\":[\"center\",\"corner\"],\"default\":\"corner\"},\"voxel_origin_point\":{\""
    "description\":\"Origin point for all voxel indices in voxel CRS.\",\"type\""
    ":\"array\",\"minItems\":3,\"maxItems\":3,\"items\":{\"type\":\"number\"}},\"voxel_t"
    "ype\":{\"description\":\"Whether a point in a voxel represents its center "
    "or its centroid. If type is <tt>index</tt> there is no point but only "
    "an integer voxel index.\",\"enum\":[\"center\",\"centroid\",\"index\"],\"default"
    "\":\"centroid\"},\"voxel_size\":{\"description\":\"Size of voxels.\",\"type\":\"ar"
    "ray\",\"minItems\":3,\"maxItems\":3,\"items\":{\"$ref\":\"#/definitions/edge_len"
    "gth\"}},\"edge_length\":{\"description\":\"Length of voxel edge [m].\",\"minim"
    "um\":0,\"exclusiveMinimum\":true,\"type\":\"number\"},\"voxel_size_cubic\":{\"$r"
    "ef\":\"#/definitions/edge_length\",\"type\":\"number\"}}}"
    ,
    /* example: */
    "{\"shape_thresholds\":{\"plane\":0.16,\"line\":6},\"reference_point\":[48,16],"
    "\"size_llcs\":[0.5156575252891171,0.5130835356683303,0.5143705304787237]"
    ",\"voxel_type\":\"centroid\",\"size\":[0.5971642834779395,0.5971642834779395"
    ",0.5143705304787237],\"voxel_origin\":\"corner\"}"
};

// Settings for waveform averaging
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS = {
    /* name        */ "riegl.waveform_averaging_settings",
    /* title       */ "Waveform Averaging Settings",
    /* description */ "Settings for waveform averaging",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Settings for waveform "
    "averaging\",\"properties\":{\"num_shots\":{\"description\":\"Number of "
    "consecutive shots to be used for averaging.\",\"minimum\":1,\"type\":\"integ"
    "er\"},\"mta_zone\":{\"description\":\"Fixed MTA zone for averaging.\",\"minimu"
    "m\":1,\"type\":\"integer\"},\"trim\":{\"description\":\"Percentage for robust av"
    "eraging.\",\"minimum\":0,\"maximum\":0.5,\"default\":0,\"type\":\"number\"}},\"tit"
    "le\":\"Waveform Averaging Settings\",\"$schema\":\"http://json-schema.org/dr"
    "aft-04/schema#\",\"type\":\"object\",\"required\":[\"num_shots\",\"mta_zone\"]}"
    ,
    /* example: */
    "{\"num_shots\":7,\"mta_zone\":1,\"trim\":0.05}"
};

// Details about waveform files
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_INFO = {
    /* name        */ "riegl.waveform_info",
    /* title       */ "Waveform Information",
    /* description */ "Details about waveform files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about waveform files\",\"properties\":{\"sample_da"
    "ta_files\":{\"items\":{\"properties\":{\"channel\":{\"description\":\"Sample "
    "block channel number (255 = invalid)\",\"exclusiveMaximum\":false,\"type\":"
    "\"integer\",\"exclusiveMinimum\":false,\"maximum\":255,\"minimum\":0},\"file_uu"
    "id\":{\"description\":\"File's Universally Unique Identifier (RFC 4122)\",\""
    "type\":\"string\"},\"delta_st\":{\"description\":\"reserved\",\"type\":\"number\"},"
    "\"file_extension\":{\"description\":\"Sample data file extension, without "
    "the leading "
    "dot\",\"type\":\"string\"},\"sample_interval\":{\"description\":\"Sampling "
    "interval in seconds\",\"minimum\":0,\"exclusiveMinimum\":false,\"type\":\"numb"
    "er\"},\"channel_name\":{\"description\":\"Sample block channel "
    "name\",\"type\":\"string\"},\"sample_bits\":{\"description\":\"Bitwidth of "
    "samples (e.g. 10 bit, 12 bit)\",\"exclusiveMaximum\":false,\"type\":\"intege"
    "r\",\"exclusiveMinimum\":false,\"maximum\":32,\"minimum\":0},\"laser_wavelengt"
    "h\":{\"description\":\"Laser wavelength in meters (0 = unknown)\",\"minimum\""
    ":0,\"exclusiveMinimum\":false,\"type\":\"number\"}},\"required\":[\"channel\",\"c"
    "hannel_name\",\"sample_interval\",\"sample_bits\",\"laser_wavelength\",\"delta"
    "_st\",\"file_extension\"],\"type\":\"object\"},\"type\":\"array\"},\"range_offset_"
    "waveform_samples_m\":{\"description\":\"Calibrated device specific range "
    "offset for waveform samples in "
    "meters.\",\"type\":\"number\"},\"range_offset_m\":{\"description\":\"Calibrated "
    "device specific range offset for waveform analysis by system response "
    "fitting in meters.\",\"type\":\"number\"},\"sample_block_file\":{\"properties\""
    ":{\"file_uuid\":{\"description\":\"File's Universally Unique Identifier "
    "(RFC 4122)\",\"type\":\"string\"},\"file_extension\":{\"description\":\"Sample "
    "block file extension, without the leading dot\",\"type\":\"string\"}},\"requ"
    "ired\":[\"file_extension\"],\"type\":\"object\"}},\"title\":\"Waveform Informati"
    "on\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object"
    "\",\"required\":[\"sample_block_file\",\"sample_data_files\"]}"
    ,
    /* example: */
    "{\"sample_data_files\":[{\"file_uuid\":\"da084413-e3e8-4655-a122-071de8490d"
    "8e\",\"channel\":0,\"delta_st\":0,\"file_extension\":\"sp0\",\"channel_name\":\"hi"
    "gh_power\",\"sample_interval\":1.00503e-09,\"laser_wavelength\":0,\"sample_b"
    "its\":12},{\"file_uuid\":\"93585b5e-5ea9-43a1-947b-e7ba3be642d2\",\"channel\""
    ":1,\"delta_st\":0,\"file_extension\":\"sp1\",\"channel_name\":\"low_power\",\"sam"
    "ple_interval\":1.00503e-09,\"laser_wavelength\":0,\"sample_bits\":12},{\"fil"
    "e_uuid\":\"9d2298c4-1036-464f-b5cb-1cf8e517f3a0\",\"channel\":5,\"delta_st\":"
    "0,\"file_extension\":\"sp5\",\"channel_name\":\"wwf\",\"sample_interval\":1.0050"
    "3e-09,\"laser_wavelength\":0,\"sample_bits\":12}],\"range_offset_waveform_s"
    "amples_m \":7.283,\"range_offset_m\":3.1415,\"sample_block_file\":{\"file_uu"
    "id\":\"93a03615-66c0-4bea-8ff8-c577378fe660\",\"file_extension\":\"sbx\"}}"
};

// Scanner settings for waveform output
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_SETTINGS = {
    /* name        */ "riegl.waveform_settings",
    /* title       */ "Waveform Settings",
    /* description */ "Scanner settings for waveform output",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Scanner settings for waveform "
    "output\",\"title\":\"Waveform Settings\",\"$schema\":\"http://json-schema.org/"
    "draft-04/schema#\",\"items\":{\"properties\":{\"enabled\":{\"description\":\"Wav"
    "eform output "
    "enabled\",\"type\":\"boolean\"},\"logic_expression\":{\"description\":\"Logic "
    "expression of smart waveforms "
    "filter\",\"type\":\"string\"},\"pass_dev_greater\":{\"description\":\"Threshold "
    "for deviation greater than "
    "[1]\",\"type\":\"integer\"},\"pass_rng_greater\":{\"description\":\"Threshold "
    "for range greater than "
    "[m]\",\"type\":\"number\"},\"pass_rng_less\":{\"description\":\"Threshold for "
    "range less than "
    "[m]\",\"type\":\"number\"},\"pass_ampl_greater\":{\"description\":\"Threshold "
    "for amplitude greater than "
    "[dB]\",\"type\":\"number\"},\"sbl_name\":{\"description\":\"Name of sample "
    "block, e.g.: wfm, "
    "wwf\",\"type\":\"string\"},\"smart_enabled\":{\"description\":\"Smart waveform "
    "output "
    "enabled\",\"type\":\"boolean\"},\"pass_ampl_less\":{\"description\":\"Threshold "
    "for amplitude less than "
    "[dB]\",\"type\":\"number\"},\"channel_idx_mask\":{\"description\":\"Bit mask for"
    " channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = "
    "Bit1, ...\",\"type\":\"integer\"},\"pass_dev_less\":{\"description\":\"Threshold"
    " for deviation less than [1]\",\"type\":\"integer\"}},\"required\":[\"sbl_name"
    "\",\"enabled\",\"channel_idx_mask\"],\"type\":\"object\"},\"type\":\"array\"}"
    ,
    /* example: */
    "[{\"enabled\":true,\"channel_idx_mask\":11,\"pass_rng_greater\":9.27,\"pass_r"
    "ng_less\":13.11,\"pass_ampl_greater\":1.0,\"sbl_name\":\"wfm\",\"smart_enabled"
    "\":true,\"pass_ampl_less\":5.0},{\"enabled\":false,\"sbl_name\":\"wwf\",\"channe"
    "l_idx_mask\":32}]"
};

// Window analysis data estimated from scandata and resulting filter parameters
const MetaDataItemInfo RDB_RIEGL_WINDOW_ANALYSIS = {
    /* name        */ "riegl.window_analysis",
    /* title       */ "Window Analysis",
    /* description */ "Window analysis data estimated from scandata and resulting filter parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Window analysis data estimated from scandata and "
    "resulting filter parameters\",\"properties\":{\"filter\":{\"properties\":{\"ra"
    "nge_max\":{\"description\":\"[m]\",\"items\":{\"type\":\"number\"},\"type\":\"array\""
    "},\"angle\":{\"description\":\"[deg]\",\"items\":{\"type\":\"number\"},\"type\":\"arr"
    "ay\"},\"range_min\":{\"description\":\"[m]\",\"items\":{\"type\":\"number\"},\"type\""
    ":\"array\"},\"amplitude_max\":{\"description\":\"[dB]\",\"items\":{\"type\":\"numbe"
    "r\"},\"type\":\"array\"}},\"required\":[\"angle\",\"range_min\",\"range_max\",\"ampl"
    "itude_max\"],\"type\":\"object\"},\"result\":{\"properties\":{\"range_mean\":{\"de"
    "scription\":\"[m]\",\"items\":{\"type\":\"number\"},\"type\":\"array\"},\"timestamp\""
    ":{\"description\":\"[s]\",\"items\":{\"type\":\"number\"},\"type\":\"array\"},\"ampli"
    "tude_sigma\":{\"description\":\"[dB]\",\"items\":{\"type\":\"number\"},\"type\":\"ar"
    "ray\"},\"amplitude_offset\":{\"description\":\"[dB]\",\"items\":{\"type\":\"number"
    "\"},\"type\":\"array\"},\"angle\":{\"description\":\"[deg]\",\"items\":{\"type\":\"num"
    "ber\"},\"type\":\"array\"},\"amplitude_mean\":{\"description\":\"[dB]\",\"items\":{"
    "\"type\":\"number\"},\"type\":\"array\"},\"range_sigma\":{\"description\":\"[m]\",\"i"
    "tems\":{\"type\":\"number\"},\"type\":\"array\"}},\"required\":[\"angle\",\"range_me"
    "an\",\"range_sigma\",\"amplitude_mean\",\"amplitude_sigma\",\"amplitude_offset"
    "\"],\"type\":\"object\"},\"settings\":{\"properties\":{\"amplitude\":{\"properties"
    "\":{\"sigma_factor\":{\"type\":\"number\"},\"additive_value\":{\"type\":\"number\"}"
    "},\"required\":[\"sigma_factor\",\"additive_value\"],\"type\":\"object\"},\"range"
    "\":{\"properties\":{\"sigma_factor\":{\"type\":\"number\"},\"additive_value\":{\"t"
    "ype\":\"number\"}},\"required\":[\"sigma_factor\",\"additive_value\"],\"type\":\"o"
    "bject\"}},\"required\":[\"range\",\"amplitude\"],\"type\":\"object\"}},\"title\":\"W"
    "indow Analysis\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"t"
    "ype\":\"object\",\"required\":[\"result\",\"filter\",\"settings\"]}"
    ,
    /* example: */
    "{\"filter\":{\"range_max\":[0.424,0.425,0.426,0.427,0.428,0.428,0.429,0.43"
    ",0.431,0.431,0.432],\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,1"
    "5.7,15.8,15.9],\"range_min\":[-0.208,-0.21,-0.212,-0.214,-0.216,-0.218,-"
    "0.219,-0.221,-0.223,-0.225,-0.227],\"amplitude_max\":[8.04,8.01,7.99,7.9"
    "6,7.93,7.9,7.88,7.85,7.83,7.8,7.78]},\"result\":{\"range_mean\":[0.1105621"
    ",0.1079564,0.1087088,0.1067261,0.1054582,0.1090412,0.102871,0.1019044,"
    "0.1051523,0.1058445,0.1031261],\"timestamp\":[408.4441,411.4443],\"amplit"
    "ude_sigma\":[0.4272844,0.4298479,0.4236816,0.4283583,0.4362353,0.431514"
    "1,0.4373984,0.4472798,0.4346001,0.4345487,0.4540681],\"amplitude_offset"
    "\":[1.9,1.9],\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8"
    ",15.9],\"amplitude_mean\":[5.347396,5.263155,5.224655,5.179926,5.097782,"
    "5.116479,5.051756,4.983473,5.007885,5.002441,4.982],\"range_sigma\":[0.0"
    "1869652,0.02151435,0.01747969,0.01918765,0.01945776,0.01934862,0.01955"
    "329,0.02225589,0.02229977,0.01899122,0.02009433]},\"settings\":{\"amplitu"
    "de\":{\"sigma_factor\":4,\"additive_value\":1.0},\"range\":{\"sigma_factor\":8,"
    "\"additive_value\":0.1}}}"
};

// Correction parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_WINDOW_ECHO_CORRECTION = {
    /* name        */ "riegl.window_echo_correction",
    /* title       */ "Window Echo Correction",
    /* description */ "Correction parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Correction parameters for window glass "
    "echoes\",\"properties\":{\"amplitude\":{\"description\":\"Amplitude axis of "
    "correction table\",\"properties\":{\"entries\":{\"description\":\"Number of "
    "amplitude entries\",\"minimum\":1,\"type\":\"integer\"},\"maximum\":{\"descripti"
    "on\":\"Maximum amplitude in "
    "dB\",\"minimum\":0.0,\"type\":\"number\"},\"minimum\":{\"description\":\"Minimum "
    "amplitude in dB\",\"minimum\":0.0,\"type\":\"number\"}},\"required\":[\"minimum\""
    ",\"maximum\",\"entries\"],\"type\":\"object\"},\"range\":{\"description\":\"Range "
    "axis of correction "
    "table\",\"properties\":{\"entries\":{\"description\":\"Number of range entries"
    "\",\"minimum\":1,\"type\":\"integer\"},\"maximum\":{\"description\":\"Maximum "
    "range in m\",\"minimum\":-2.0,\"maximum\":2.0,\"type\":\"number\"},\"minimum\":{\""
    "description\":\"Minimum range in m\",\"minimum\":-2.0,\"maximum\":2.0,\"type\":"
    "\"number\"}},\"required\":[\"minimum\",\"maximum\",\"entries\"],\"type\":\"object\"}"
    ",\"slices\":{\"items\":{\"description\":\"Window echo correction parameter "
    "slice\",\"properties\":{\"amplitude\":{\"description\":\"Window echo amplitude"
    " of slice in dB\",\"type\":\"number\"},\"table\":{\"description\":\"Correction "
    "table (dimension defined by the 'amplitude' and 'range' "
    "objects)\",\"items\":{\"description\":\"Table row (= amplitude "
    "axis)\",\"items\":{\"description\":\"Table column (= range "
    "axis)\",\"items\":{\"description\":\"Table cell (item 0: amplitude in dB, 1:"
    " range in m, 2: flags)\",\"type\":\"number\"},\"minItems\":3,\"maxItems\":3,\"ty"
    "pe\":\"array\"},\"minItems\":1,\"type\":\"array\"},\"minItems\":1,\"type\":\"array\"}"
    "},\"required\":[\"amplitude\",\"table\"],\"type\":\"object\"},\"type\":\"array\"}},\""
    "title\":\"Window Echo Correction\",\"$schema\":\"http://json-schema.org/draf"
    "t-04/schema#\",\"type\":\"object\",\"required\":[\"amplitude\",\"range\",\"slices\""
    "]}"
    ,
    /* example: */
    "{\"amplitude\":{\"entries\":128,\"maximum\":20,\"minimum\":2},\"range\":{\"entrie"
    "s\":128,\"maximum\":1.5060822940732335,\"minimum\":-1.5060822940732335},\"sl"
    "ices\":[{\"amplitude\":1.5,\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]]"
    "},{\"amplitude\":2.0,\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]]}]}"
};

// Table of all meta data item details records
const MetaDataItemInfo* const RDB_META_DATA_ITEMS[] = {
    &RDB_RIEGL_ANGULAR_NOTCH_FILTER,
    &RDB_RIEGL_ATMOSPHERE,
    &RDB_RIEGL_BEAM_GEOMETRY,
    &RDB_RIEGL_CONTROL_OBJECT_CATALOG,
    &RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE,
    &RDB_RIEGL_DETECTION_PROBABILITY,
    &RDB_RIEGL_DEVICE,
    &RDB_RIEGL_DEVICE_GEOMETRY,
    &RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL,
    &RDB_RIEGL_DEVICE_OUTPUT_LIMITS,
    &RDB_RIEGL_DEVICES,
    &RDB_RIEGL_DYNTRIG,
    &RDB_RIEGL_ECHO_INFO,
    &RDB_RIEGL_EXPONENTIAL_DECOMPOSITION,
    &RDB_RIEGL_GAUSSIAN_DECOMPOSITION,
    &RDB_RIEGL_GEO_TAG,
    &RDB_RIEGL_GEOMETRIC_SCALE_FACTOR,
    &RDB_RIEGL_GEOREFERENCING_PARAMETERS,
    &RDB_RIEGL_ITEM_NAMES,
    &RDB_RIEGL_LICENSES,
    &RDB_RIEGL_MTA_SETTINGS,
    &RDB_RIEGL_NEAR_RANGE_CORRECTION,
    &RDB_RIEGL_NOISE_ESTIMATES,
    &RDB_RIEGL_NOTCH_FILTER,
    &RDB_RIEGL_PIXEL_INFO,
    &RDB_RIEGL_PLANE_PATCH_MATCHING,
    &RDB_RIEGL_PLANE_PATCH_STATISTICS,
    &RDB_RIEGL_PLANE_SLOPE_CLASS_INFO,
    &RDB_RIEGL_POINT_ATTRIBUTE_GROUPS,
    &RDB_RIEGL_POINTCLOUD_INFO,
    &RDB_RIEGL_POSE_ESTIMATION,
    &RDB_RIEGL_POSE_SENSORS,
    &RDB_RIEGL_PULSE_POSITION_MODULATION,
    &RDB_RIEGL_RANGE_STATISTICS,
    &RDB_RIEGL_RECEIVER_INTERNALS,
    &RDB_RIEGL_REFLECTANCE_CALCULATION,
    &RDB_RIEGL_REFLECTANCE_CORRECTION,
    &RDB_RIEGL_SCAN_PATTERN,
    &RDB_RIEGL_SHOT_INFO,
    &RDB_RIEGL_STORED_FILTERS,
    &RDB_RIEGL_SYSTEM_DESCRIPTION,
    &RDB_RIEGL_TEMPERATURE_CALCULATION,
    &RDB_RIEGL_TIME_BASE,
    &RDB_RIEGL_TRAJECTORY_INFO,
    &RDB_RIEGL_TTIP_CONFIGURATION,
    &RDB_RIEGL_VERTEX_INFO,
    &RDB_RIEGL_VOXEL_INFO,
    &RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS,
    &RDB_RIEGL_WAVEFORM_INFO,
    &RDB_RIEGL_WAVEFORM_SETTINGS,
    &RDB_RIEGL_WINDOW_ANALYSIS,
    &RDB_RIEGL_WINDOW_ECHO_CORRECTION
};
const std::size_t RDB_META_DATA_ITEM_COUNT(
    sizeof(RDB_META_DATA_ITEMS) / sizeof(RDB_META_DATA_ITEMS[0])
);
const std::vector<const MetaDataItemInfo*> RDB_META_DATA_ITEMS_VECTOR(
    RDB_META_DATA_ITEMS, RDB_META_DATA_ITEMS + RDB_META_DATA_ITEM_COUNT
);

}}} // namespace riegl::rdb::pointcloud

#endif // RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
